@@ -1,5 +1,5 @@
 /*
-** Copyright 2011-2017 Centreon
+** Copyright 2011-2019 Centreon
 **
 ** This file is part of Centreon Engine.
 **
@@ -18,21 +18,18 @@
 */
 
 #include <algorithm>
+#include <cassert>
 #include "com/centreon/engine/broker.hh"
 #include "com/centreon/engine/config.hh"
-#include "com/centreon/engine/configuration/applier/service.hh"
-#include "com/centreon/engine/configuration/applier/object.hh"
 #include "com/centreon/engine/configuration/applier/scheduler.hh"
-#include "com/centreon/engine/configuration/applier/state.hh"
-#include "com/centreon/engine/deleter/contactgroupsmember.hh"
-#include "com/centreon/engine/deleter/contactsmember.hh"
-#include "com/centreon/engine/deleter/listmember.hh"
-#include "com/centreon/engine/deleter/objectlist.hh"
+#include "com/centreon/engine/configuration/applier/service.hh"
+#include "com/centreon/engine/downtimes/downtime_manager.hh"
 #include "com/centreon/engine/error.hh"
 #include "com/centreon/engine/globals.hh"
 
 using namespace com::centreon;
 using namespace com::centreon::engine;
+using namespace com::centreon::engine::downtimes;
 using namespace com::centreon::engine::configuration;
 
 /**
@@ -45,8 +42,8 @@ public:
     _servicegroup_name = servicegroup_name;
   }
 
-  bool        operator()(shared_ptr<configuration::servicegroup> sg) {
-    return (_servicegroup_name == sg->servicegroup_name());
+  bool        operator()(std::shared_ptr<configuration::servicegroup> sg) {
+    return _servicegroup_name == sg->servicegroup_name();
   }
 
 private:
@@ -70,7 +67,7 @@ applier::service::service(applier::service const& right) {
 /**
  *  Destructor.
  */
-applier::service::~service() throw () {}
+applier::service::~service() {}
 
 /**
  *  Assignment operator.
@@ -82,7 +79,7 @@ applier::service::~service() throw () {}
 applier::service& applier::service::operator=(
                                       applier::service const& right) {
   (void)right;
-  return (*this);
+  return *this;
 }
 
 /**
@@ -93,14 +90,22 @@ applier::service& applier::service::operator=(
 void applier::service::add_object(
                          configuration::service const& obj) {
   // Check service.
-  if (obj.hosts().size() != 1)
-    throw (engine_error() << "Could not create service '"
+  if (obj.hosts().size() < 1)
+    throw engine_error() << "Could not create service '"
            << obj.service_description()
-           << "' with multiple hosts defined");
+           << "' with no host defined";
+  else if (obj.hosts().size() > 1)
+    throw engine_error() << "Could not create service '"
+           << obj.service_description()
+           << "' with multiple hosts defined";
   else if (!obj.hostgroups().empty())
-    throw (engine_error() << "Could not create service '"
+    throw engine_error() << "Could not create service '"
            << obj.service_description()
-           << "' with multiple host groups defined");
+           << "' with multiple host groups defined";
+  else if (!obj.host_id())
+    throw engine_error() << "No host_id available for the host '"
+           << *obj.hosts().begin() << "' - unable to create service '"
+           << obj.service_description() << "'";
 
   // Logging.
   logger(logging::dbg_config, logging::more)
@@ -111,20 +116,21 @@ void applier::service::add_object(
   config->services().insert(obj);
 
   // Create service.
-  service_struct* svc(add_service(
-    obj.hosts().begin()->c_str(),
-    obj.service_description().c_str(),
-    NULL_IF_EMPTY(obj.display_name()),
-    NULL_IF_EMPTY(obj.check_period()),
-    obj.initial_state(),
+  engine::service* svc{add_service(
+    obj.host_id(),
+    obj.service_id(),
+    *obj.hosts().begin(),
+    obj.service_description(),
+    obj.display_name(),
+    obj.check_period(),
+    static_cast<engine::service::service_state>(obj.initial_state()),
     obj.max_check_attempts(),
-    true, // parallelize, enabled by default in Nagios
-    obj.checks_passive(),
     obj.check_interval(),
     obj.retry_interval(),
     obj.notification_interval(),
     obj.first_notification_delay(),
-    NULL_IF_EMPTY(obj.notification_period()),
+    obj.recovery_notification_delay(),
+    obj.notification_period(),
     static_cast<bool>(obj.notification_options()
                       & configuration::service::ok),
     static_cast<bool>(obj.notification_options()
@@ -139,10 +145,11 @@ void applier::service::add_object(
                       & configuration::service::downtime),
     obj.notifications_enabled(),
     obj.is_volatile(),
-    NULL_IF_EMPTY(obj.event_handler()),
+    obj.event_handler(),
     obj.event_handler_enabled(),
-    NULL_IF_EMPTY(obj.check_command()),
+    obj.check_command(),
     obj.checks_active(),
+    obj.checks_passive(),
     obj.flap_detection_enabled(),
     obj.low_flap_threshold(),
     obj.high_flap_threshold(),
@@ -163,47 +170,31 @@ void applier::service::add_object(
     static_cast<bool>(obj.stalking_options()
                       &configuration::service::critical),
     obj.process_perf_data(),
-    false, // failure_prediction_enabled
-    NULL, // failure_prediction_options
     obj.check_freshness(),
     obj.freshness_threshold(),
-    NULL_IF_EMPTY(obj.notes()),
-    NULL_IF_EMPTY(obj.notes_url()),
-    NULL_IF_EMPTY(obj.action_url()),
-    NULL_IF_EMPTY(obj.icon_image()),
-    NULL_IF_EMPTY(obj.icon_image_alt()),
+    obj.notes(),
+    obj.notes_url(),
+    obj.action_url(),
+    obj.icon_image(),
+    obj.icon_image_alt(),
     obj.retain_status_information(),
     obj.retain_nonstatus_information(),
-    obj.obsess_over_service()));
+    obj.obsess_over_service(),
+    obj.timezone())};
   if (!svc)
-      throw (engine_error() << "Could not register service '"
+      throw engine_error() << "Could not register service '"
              << obj.service_description()
-             << "' of host '" << *obj.hosts().begin() << "'");
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].initial_notif_time = 0;
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].timezone = obj.timezone();
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].host_id = obj.host_id();
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].service_id = obj.service_id();
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].acknowledgement_timeout
-    = obj.get_acknowledgement_timeout() * config->interval_length();
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].last_acknowledgement = 0;
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].recovery_notification_delay = obj.recovery_notification_delay();
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].recovery_been_sent = true;
+             << "' of host '" << *obj.hosts().begin() << "'";
+  svc->set_initial_notif_time(0);
+  engine::service::services[
+    {*obj.hosts().begin(), obj.service_description()}]->set_host_id(
+      obj.host_id());
+  engine::service::services[
+    {*obj.hosts().begin(), obj.service_description()}]->set_service_id(
+      obj.service_id());
+  svc->set_acknowledgement_timeout(obj.get_acknowledgement_timeout() *
+                                   config->interval_length());
+  svc->set_last_acknowledgement(0);
 
   // Add contacts.
   for (set_string::const_iterator
@@ -211,10 +202,7 @@ void applier::service::add_object(
          end(obj.contacts().end());
        it != end;
        ++it)
-    if (!add_contact_to_service(svc, it->c_str()))
-      throw (engine_error() << "Could not add contact '"
-             << *it << "' to service '" << obj.service_description()
-             << "' of host '" << *obj.hosts().begin() << "'");
+    svc->get_contacts().insert({*it, nullptr});
 
   // Add contactgroups.
   for (set_string::const_iterator
@@ -222,25 +210,23 @@ void applier::service::add_object(
          end(obj.contactgroups().end());
        it != end;
        ++it)
-    if (!add_contactgroup_to_service(svc, it->c_str()))
-      throw (engine_error() << "Could not add contact group '"
-             << *it << "' to service '" << obj.service_description()
-             << "' of host '" << *obj.hosts().begin() << "'");
+    svc->get_contactgroups().insert({*it, nullptr});
 
   // Add custom variables.
   for (map_customvar::const_iterator
          it(obj.customvariables().begin()),
          end(obj.customvariables().end());
        it != end;
-       ++it)
-    if (!add_custom_variable_to_service(
-           svc,
-           it->first.c_str(),
-           it->second.c_str()))
-      throw (engine_error() << "Could not add custom variable '"
-             << it->first << "' to service '"
-             << obj.service_description() << "' of host '"
-             << *obj.hosts().begin() << "'");
+       ++it) {
+    svc->custom_variables[it->first] =  it->second;
+
+    if (it->second.is_sent()) {
+      timeval tv(get_broker_timestamp(nullptr));
+      broker_custom_variable(NEBTYPE_SERVICECUSTOMVARIABLE_ADD, NEBFLAG_NONE,
+                             NEBATTR_NONE, svc, it->first.c_str(),
+                             it->second.get_value().c_str(), &tv);
+      }
+  }
 
   // Notify event broker.
   timeval tv(get_broker_timestamp(NULL));
@@ -253,8 +239,6 @@ void applier::service::add_object(
     MODATTR_ALL,
     MODATTR_ALL,
     &tv);
-
-  return ;
 }
 
 /**
@@ -270,6 +254,18 @@ void applier::service::expand_objects(configuration::state& s) {
          end_svc(s.services().end());
        it_svc != end_svc;
        ++it_svc) {
+    // Should custom variables be sent to broker ?
+    for (map_customvar::iterator
+           it(const_cast<map_customvar&>(it_svc->customvariables()).begin()),
+           end(const_cast<map_customvar&>(it_svc->customvariables()).end());
+         it != end;
+         ++it) {
+      if (!s.enable_macros_filter()
+          || s.macros_filter().find(it->first) != s.macros_filter().end()) {
+        it->second.set_sent(true);
+      }
+    }
+
     // Expand service to instances.
     std::set<std::string> target_hosts;
 
@@ -328,7 +324,6 @@ void applier::service::expand_objects(configuration::state& s) {
   // Set expanded services in configuration state.
   s.services().swap(expanded);
 
-  return ;
 }
 
 /**
@@ -350,18 +345,18 @@ void applier::service::modify_object(
   // Find the configuration object.
   set_service::iterator it_cfg(config->services_find(obj.key()));
   if (it_cfg == config->services().end())
-    throw (engine_error() << "Cannot modify non-existing "
+    throw engine_error() << "Cannot modify non-existing "
            "service '" << service_description << "' of host '"
-           << host_name << "'");
+           << host_name << "'";
 
   // Find service object.
-  umap<std::pair<std::string, std::string>, shared_ptr<service_struct> >::iterator
-    it_obj(applier::state::instance().services_find(obj.key()));
-  if (it_obj == applier::state::instance().services().end())
-    throw (engine_error() << "Could not modify non-existing "
+  service_id_map::iterator it_obj(engine::service::services_by_id.find(
+    obj.key()));
+  if (it_obj == engine::service::services_by_id.end())
+    throw engine_error() << "Could not modify non-existing "
            << "service object '" << service_description
-           << "' of host '" << host_name << "'");
-  service_struct* s(it_obj->second.get());
+           << "' of host '" << host_name << "'";
+  std::shared_ptr<engine::service> s{it_obj->second};
 
   // Update the global configuration set.
   configuration::service obj_old(*it_cfg);
@@ -369,169 +364,94 @@ void applier::service::modify_object(
   config->services().insert(obj);
 
   // Modify properties.
-  modify_if_different(
-    s->display_name,
-    NULL_IF_EMPTY(obj.display_name()));
-  modify_if_different(
-    s->service_check_command,
-    NULL_IF_EMPTY(obj.check_command()));
-  modify_if_different(
-    s->event_handler,
-    NULL_IF_EMPTY(obj.event_handler()));
-  modify_if_different(
-    s->event_handler_enabled,
-    static_cast<int>(obj.event_handler_enabled()));
-  modify_if_different(
-    s->initial_state,
-    static_cast<int>(obj.initial_state()));
-  modify_if_different(
-    s->check_interval,
-    static_cast<double>(obj.check_interval()));
-  modify_if_different(
-    s->retry_interval,
-    static_cast<double>(obj.retry_interval()));
-  modify_if_different(
-    s->max_attempts,
-    static_cast<int>(obj.max_check_attempts()));
-  modify_if_different(
-    s->notification_interval,
-    static_cast<double>(obj.notification_interval()));
-  modify_if_different(
-    s->first_notification_delay,
-    static_cast<double>(obj.first_notification_delay()));
-  modify_if_different(
-    s->notify_on_unknown,
-    static_cast<int>(static_cast<bool>(
-      obj.notification_options() & configuration::service::unknown)));
-  modify_if_different(
-    s->notify_on_warning,
-    static_cast<int>(static_cast<bool>(
-      obj.notification_options() & configuration::service::warning)));
-  modify_if_different(
-    s->notify_on_critical,
-    static_cast<int>(static_cast<bool>(
-      obj.notification_options() & configuration::service::critical)));
-  modify_if_different(
-    s->notify_on_recovery,
-    static_cast<int>(static_cast<bool>(
-      obj.notification_options() & configuration::service::ok)));
-  modify_if_different(
-    s->notify_on_flapping,
-    static_cast<int>(static_cast<bool>(
-      obj.notification_options() & configuration::service::flapping)));
-  modify_if_different(
-    s->notify_on_downtime,
-    static_cast<int>(static_cast<bool>(
-      obj.notification_options() & configuration::service::downtime)));
-  modify_if_different(
-    s->stalk_on_ok,
-    static_cast<int>(static_cast<bool>(
-      obj.stalking_options() & configuration::service::ok)));
-  modify_if_different(
-    s->stalk_on_warning,
-    static_cast<int>(static_cast<bool>(
-      obj.stalking_options() & configuration::service::warning)));
-  modify_if_different(
-    s->stalk_on_unknown,
-    static_cast<int>(static_cast<bool>(
-      obj.stalking_options() & configuration::service::unknown)));
-  modify_if_different(
-    s->stalk_on_critical,
-    static_cast<int>(static_cast<bool>(
-      obj.stalking_options() & configuration::service::critical)));
-  modify_if_different(
-    s->notification_period,
-    NULL_IF_EMPTY(obj.notification_period()));
-  modify_if_different(
-    s->check_period,
-    NULL_IF_EMPTY(obj.check_period()));
-  modify_if_different(
-    s->flap_detection_enabled,
-    static_cast<int>(obj.flap_detection_enabled()));
-  modify_if_different(
-    s->low_flap_threshold,
-    static_cast<double>(obj.low_flap_threshold()));
-  modify_if_different(
-    s->high_flap_threshold,
-    static_cast<double>(obj.high_flap_threshold()));
-  modify_if_different(
-    s->flap_detection_on_ok,
-    static_cast<int>(static_cast<bool>(
-      obj.flap_detection_options() & configuration::service::ok)));
-  modify_if_different(
-    s->flap_detection_on_warning,
-    static_cast<int>(static_cast<bool>(
-      obj.flap_detection_options() & configuration::service::warning)));
-  modify_if_different(
-    s->flap_detection_on_unknown,
-    static_cast<int>(static_cast<bool>(
-      obj.flap_detection_options() & configuration::service::unknown)));
-  modify_if_different(
-    s->flap_detection_on_critical,
-    static_cast<int>(static_cast<bool>(
-      obj.flap_detection_options() & configuration::service::critical)));
-  modify_if_different(
-    s->process_performance_data,
-    static_cast<int>(obj.process_perf_data()));
-  modify_if_different(
-    s->check_freshness,
-    static_cast<int>(obj.check_freshness()));
-  modify_if_different(
-    s->freshness_threshold,
-    static_cast<int>(obj.freshness_threshold()));
-  modify_if_different(
-    s->accept_passive_service_checks,
-    static_cast<int>(obj.checks_passive()));
-  modify_if_different(
-    s->event_handler,
-    NULL_IF_EMPTY(obj.event_handler()));
-  modify_if_different(
-    s->checks_enabled,
-    static_cast<int>(obj.checks_active()));
-  modify_if_different(
-    s->retain_status_information,
-    static_cast<int>(obj.retain_status_information()));
-  modify_if_different(
-    s->retain_nonstatus_information,
-    static_cast<int>(obj.retain_nonstatus_information()));
-  modify_if_different(
-    s->notifications_enabled,
-    static_cast<int>(obj.notifications_enabled()));
-  modify_if_different(
-    s->obsess_over_service,
-    static_cast<int>(obj.obsess_over_service()));
-  modify_if_different(s->notes, NULL_IF_EMPTY(obj.notes()));
-  modify_if_different(s->notes_url, NULL_IF_EMPTY(obj.notes_url()));
-  modify_if_different(s->action_url, NULL_IF_EMPTY(obj.action_url()));
-  modify_if_different(s->icon_image, NULL_IF_EMPTY(obj.icon_image()));
-  modify_if_different(
-    s->icon_image_alt,
-    NULL_IF_EMPTY(obj.icon_image_alt()));
-  modify_if_different(
-    s->is_volatile,
-    static_cast<int>(obj.is_volatile()));
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].timezone = obj.timezone();
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].host_id = obj.host_id();
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].service_id = obj.service_id();
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].acknowledgement_timeout
-    = obj.get_acknowledgement_timeout() * config->interval_length();
-  service_other_props[std::make_pair(
-                             *obj.hosts().begin(),
-                             obj.service_description())].recovery_notification_delay
-    = obj.recovery_notification_delay();
+  if(it_obj->second->get_hostname() != *obj.hosts().begin() ||
+       it_obj->second->get_description() != obj.service_description()) {
+    engine::service::services.erase({it_obj->second->get_hostname(),
+                                     it_obj->second->get_description()});
+    engine::service::services.insert({{*obj.hosts().begin(),
+                                       obj.service_description()},
+                                      it_obj->second});
+  }
+
+  s->set_hostname(*obj.hosts().begin());
+  s->set_description(obj.service_description());
+  s->set_display_name(obj.display_name()),
+  s->set_check_command(obj.check_command());
+  s->set_event_handler(obj.event_handler());
+  s->set_event_handler_enabled(obj.event_handler_enabled());
+  s->set_initial_state(static_cast<engine::service::service_state>(obj.initial_state()));
+  s->set_check_interval(obj.check_interval());
+  s->set_retry_interval(obj.retry_interval());
+  s->set_max_attempts(obj.max_check_attempts());
+
+  s->set_notify_on(
+      (obj.notification_options() & configuration::service::unknown
+           ? notifier::unknown
+           : notifier::none) |
+      (obj.notification_options() & configuration::service::warning
+           ? notifier::warning
+           : notifier::none) |
+      (obj.notification_options() & configuration::service::critical
+           ? notifier::critical
+           : notifier::none) |
+      (obj.notification_options() & configuration::service::ok
+           ? notifier::ok
+           : notifier::none) |
+      (obj.notification_options() & configuration::service::flapping
+           ? (notifier::flappingstart | notifier::flappingstop |
+              notifier::flappingdisabled)
+           : notifier::none) |
+      (obj.notification_options() & configuration::service::downtime
+           ? notifier::downtime
+           : notifier::none));
+
+  s->set_notification_interval(static_cast<double>(obj.notification_interval()));
+  s->set_first_notification_delay(static_cast<double>(obj.first_notification_delay()));
+
+  s->add_stalk_on(obj.notification_options() & configuration::service::ok ? notifier::ok : notifier::none);
+  s->add_stalk_on(obj.notification_options() & configuration::service::warning ? notifier::warning : notifier::none);
+  s->add_stalk_on(obj.notification_options() & configuration::service::unknown ? notifier::unknown : notifier::none);
+  s->add_stalk_on(obj.notification_options() & configuration::service::critical ? notifier::critical : notifier::none);
+
+  s->set_notification_period(obj.notification_period());
+  s->set_check_period(obj.check_period());
+  s->set_flap_detection_enabled(obj.flap_detection_enabled());
+  s->set_low_flap_threshold(obj.low_flap_threshold());
+  s->set_high_flap_threshold(obj.high_flap_threshold());
+
+  s->set_flap_detection_on(notifier::none);
+  s->add_flap_detection_on(obj.flap_detection_options() & configuration::service::ok ? notifier::ok : notifier::none);
+  s->add_flap_detection_on(obj.flap_detection_options() & configuration::service::warning ? notifier::warning : notifier::none);
+  s->add_flap_detection_on(obj.flap_detection_options() & configuration::service::unknown ? notifier::unknown : notifier::none);
+  s->add_flap_detection_on(obj.flap_detection_options() & configuration::service::critical ? notifier::critical : notifier::none);
+
+  s->set_process_performance_data(static_cast<int>(obj.process_perf_data()));
+  s->set_check_freshness(obj.check_freshness());
+  s->set_freshness_threshold(obj.freshness_threshold());
+  s->set_accept_passive_checks(obj.checks_passive());
+  s->set_event_handler(obj.event_handler());
+  s->set_checks_enabled(obj.checks_active());
+  s->set_retain_status_information(static_cast<bool>(obj.retain_status_information()));
+  s->set_retain_nonstatus_information(static_cast<bool>(obj.retain_nonstatus_information()));
+  s->set_notifications_enabled(obj.notifications_enabled());
+  s->set_obsess_over(obj.obsess_over_service());
+  s->set_notes(obj.notes());
+  s->set_notes_url(obj.notes_url());
+  s->set_action_url(obj.action_url());
+  s->set_icon_image(obj.icon_image());
+  s->set_icon_image_alt(obj.icon_image_alt());
+  s->set_is_volatile(obj.is_volatile());
+  s->set_timezone(obj.timezone());
+  s->set_host_id(obj.host_id());
+  s->set_service_id(obj.service_id());
+  s->set_acknowledgement_timeout(obj.get_acknowledgement_timeout() *
+                                   config->interval_length());
+  s->set_recovery_notification_delay(obj.recovery_notification_delay());
 
   // Contacts.
   if (obj.contacts() != obj_old.contacts()) {
     // Delete old contacts.
-    deleter::listmember(s->contacts, &deleter::contactsmember);
+    s->get_contacts().clear();
 
     // Add contacts to host.
     for (set_string::const_iterator
@@ -539,18 +459,13 @@ void applier::service::modify_object(
            end(obj.contacts().end());
          it != end;
          ++it)
-      if (!add_contact_to_service(s, it->c_str()))
-        throw (engine_error() << "Could not add contact '"
-               << *it << "' to service '" << service_description
-               << "' on host '" << host_name << "'");
+      s->get_contacts().insert({*it, nullptr});
   }
 
   // Contact groups.
   if (obj.contactgroups() != obj_old.contactgroups()) {
     // Delete old contact groups.
-    deleter::listmember(
-      s->contact_groups,
-      &deleter::contactgroupsmember);
+    s->get_contactgroups().clear();
 
     // Add contact groups to host.
     for (set_string::const_iterator
@@ -558,30 +473,31 @@ void applier::service::modify_object(
            end(obj.contactgroups().end());
          it != end;
          ++it)
-      if (!add_contactgroup_to_service(s, it->c_str()))
-        throw (engine_error() << "Could not add contact group '"
-               << *it << "' to service '" << service_description
-               << "' on host '" << host_name << "'");
+      s->get_contactgroups().insert({*it, nullptr});
   }
 
   // Custom variables.
   if (obj.customvariables() != obj_old.customvariables()) {
-    // Delete old custom variables.
-    remove_all_custom_variables_from_service(s);
+    for (auto& c : s->custom_variables) {
+      if (c.second.is_sent()) {
+        timeval tv(get_broker_timestamp(nullptr));
+        broker_custom_variable(
+            NEBTYPE_SERVICECUSTOMVARIABLE_DELETE, NEBFLAG_NONE, NEBATTR_NONE,
+            s.get(), c.first.c_str(), c.second.get_value().c_str(), &tv);
+      }
+    }
+    s->custom_variables.clear();
 
-    // Add custom variables.
-    for (map_customvar::const_iterator
-           it(obj.customvariables().begin()),
-           end(obj.customvariables().end());
-         it != end;
-         ++it)
-      if (!add_custom_variable_to_service(
-             s,
-             it->first.c_str(),
-             it->second.c_str()))
-        throw (engine_error() << "Could not add custom variable '"
-               << it->first << "' to service '" << service_description
-               << "' on host '" << host_name << "'");
+    for (auto& c: obj.customvariables()) {
+      s->custom_variables[c.first] =  c.second;
+
+      if (c.second.is_sent()) {
+        timeval tv(get_broker_timestamp(nullptr));
+        broker_custom_variable(NEBTYPE_SERVICECUSTOMVARIABLE_ADD, NEBFLAG_NONE,
+                               NEBATTR_NONE, s.get(), c.first.c_str(),
+                               c.second.get_value().c_str(), &tv);
+      }
+    }
   }
 
   // Notify event broker.
@@ -590,12 +506,11 @@ void applier::service::modify_object(
     NEBTYPE_SERVICE_UPDATE,
     NEBFLAG_NONE,
     NEBATTR_NONE,
-    s,
+    s.get(),
     CMD_NONE,
     MODATTR_ALL,
     MODATTR_ALL,
     &tv);
-  return ;
 }
 
 /**
@@ -609,43 +524,34 @@ void applier::service::remove_object(
   std::string const& host_name(*obj.hosts().begin());
   std::string const& service_description(obj.service_description());
 
+  assert(obj.key().first);
   // Logging.
   logger(logging::dbg_config, logging::more)
     << "Removing service '" << service_description
     << "' of host '" << host_name << "'.";
 
   // Find service.
-  std::pair<std::string, std::string>
-    id(std::make_pair(host_name, service_description));
-  umap<std::pair<std::string, std::string>, shared_ptr<service_struct> >::iterator
-    it(applier::state::instance().services_find(obj.key()));
-  if (it != applier::state::instance().services().end()) {
-    service_struct* svc(it->second.get());
+  service_id_map::iterator
+    it(engine::service::services_by_id.find(obj.key()));
+  if (it != engine::service::services_by_id.end()) {
+    std::shared_ptr<engine::service> svc(it->second);
 
     // Remove service comments.
-    delete_all_service_comments(
-      host_name.c_str(),
-      service_description.c_str());
+    comment::delete_service_comments(host_name, service_description);
 
     // Remove service downtimes.
-    delete_downtime_by_hostname_service_description_start_time_comment(
-      host_name.c_str(),
-      service_description.c_str(),
+    downtime_manager::instance().delete_downtime_by_hostname_service_description_start_time_comment(
+      host_name,
+      service_description,
       (time_t)0,
-      NULL);
+      "");
 
     // Remove events related to this service.
     applier::scheduler::instance().remove_service(obj);
 
-    // Unregister service.
-    for (service_struct** s(&service_list); *s; s = &(*s)->next)
-      if (!strcmp((*s)->host_name, host_name.c_str())
-          && !strcmp(
-                (*s)->description,
-                service_description.c_str())) {
-        *s = (*s)->next;
-        break ;
-      }
+    //remove service from servicegroup->members
+    for (auto& it_s: it->second->get_parent_groups())
+      it_s->members.erase({host_name, service_description});
 
     // Notify event broker.
     timeval tv(get_broker_timestamp(NULL));
@@ -653,23 +559,19 @@ void applier::service::remove_object(
       NEBTYPE_SERVICE_DELETE,
       NEBFLAG_NONE,
       NEBATTR_NONE,
-      svc,
+      svc.get(),
       CMD_NONE,
       MODATTR_ALL,
       MODATTR_ALL,
       &tv);
 
-    // Remove service object (will effectively delete the object).
-    service_other_props.erase(std::make_pair(
-                                     *obj.hosts().begin(),
-                                     obj.service_description()));
-    applier::state::instance().services().erase(it);
+    // Unregister service.
+    engine::service::services.erase({host_name, service_description});
+    engine::service::services_by_id.erase(it);
   }
 
   // Remove service from the global configuration set.
   config->services().erase(obj);
-
-  return ;
 }
 
 /**
@@ -685,34 +587,26 @@ void applier::service::resolve_object(
     << "' of host '" << *obj.hosts().begin() << "'.";
 
   // Find service.
-  umap<std::pair<std::string, std::string>, shared_ptr<service_struct> >::iterator
-    it(applier::state::instance().services_find(obj.key()));
-  if (applier::state::instance().services().end() == it)
-    throw (engine_error() << "Cannot resolve non-existing service '"
+  service_id_map::iterator it(engine::service::services_by_id.find(obj.key()));
+  if (engine::service::services_by_id.end() == it)
+    throw engine_error() << "Cannot resolve non-existing service '"
            << obj.service_description() << "' of host '"
-           << *obj.hosts().begin() << "'");
+           << *obj.hosts().begin() << "'";
 
   // Remove service group links.
-  deleter::listmember(
-    it->second->servicegroups_ptr,
-    &deleter::objectlist);
+  it->second->get_parent_groups().clear();
 
   // Find host and adjust its counters.
-  umap<std::string, shared_ptr<host_struct> >::iterator
-    hst(applier::state::instance().hosts_find(it->second->host_name));
-  if (hst != applier::state::instance().hosts().end()) {
-    ++hst->second->total_services;
-    hst->second->total_service_check_interval
-      += static_cast<unsigned long>(it->second->check_interval);
+  host_id_map::iterator hst(engine::host::hosts_by_id.find(it->first.first));
+  if (hst != engine::host::hosts_by_id.end()) {
+    hst->second->set_total_services(hst->second->get_total_services() + 1);
+    hst->second->set_total_service_check_interval(
+      hst->second->get_total_service_check_interval() +
+      static_cast<uint64_t>(it->second->get_check_interval()));
   }
 
   // Resolve service.
-  if (!check_service(it->second.get(), &config_warnings, &config_errors))
-      throw (engine_error() << "Cannot resolve service '"
-             << obj.service_description() << "' of host '"
-             << *obj.hosts().begin() << "'");
-
-  return ;
+  it->second->resolve(config_warnings, config_errors);
 }
 
 /**
@@ -777,16 +671,16 @@ void applier::service::_inherits_special_vars(
       || !obj.timezone_defined()) {
     // Find host.
     configuration::set_host::const_iterator
-      it(s.hosts_find(*obj.hosts().begin()));
+      it(s.hosts_find(obj.hosts().begin()->c_str()));
     if (it == s.hosts().end())
-      throw (engine_error()
+      throw engine_error()
              << "Could not inherit special variables for service '"
              << obj.service_description() << "': host '"
-             << *obj.hosts().begin() << "' does not exist");
+             << *obj.hosts().begin() << "' does not exist";
 
     // Inherits variables.
     if (!obj.host_id())
-      obj.host_id(it->host_id());
+      obj.set_host_id(it->host_id());
     if (!obj.contacts_defined() && !obj.contactgroups_defined()) {
       obj.contacts() = it->contacts();
       obj.contactgroups() = it->contactgroups();
@@ -798,6 +692,4 @@ void applier::service::_inherits_special_vars(
     if (!obj.timezone_defined())
       obj.timezone(it->timezone());
   }
-
-  return ;
 }
