@@ -48,7 +48,7 @@ void adjust_check_scheduling() {
   int total_checks(0);
   time_t last_check_time(0L);
   host* hst(NULL);
-  service* svc(NULL);
+  com::centreon::engine::service* svc(NULL);
 
   logger(dbg_functions, basic)
     << "adjust_check_scheduling()";
@@ -64,27 +64,31 @@ void adjust_check_scheduling() {
   time_t last_window_time(first_window_time + config->auto_rescheduling_window());
 
   // get current scheduling data.
-  for (timed_event* tmp(event_list_low); tmp; tmp = tmp->next) {
+  for (timed_event_list::iterator
+         it{timed_event::event_list_low.begin()},
+         end{timed_event::event_list_low.end()};
+       it != end;
+       ++it) {
     // skip events outside of our current window.
-    if (tmp->run_time <= first_window_time)
+    if ((*it)->run_time <= first_window_time)
       continue;
-    if (tmp->run_time > last_window_time)
+    if ((*it)->run_time > last_window_time)
       break;
 
-    if (tmp->event_type == EVENT_HOST_CHECK) {
+    if ((*it)->event_type == EVENT_HOST_CHECK) {
 
-      if (!(hst = (host*)tmp->event_data))
+      if (!(hst = (host*)(*it)->event_data))
         continue;
 
       // ignore forced checks.
-      if (hst->check_options & CHECK_OPTION_FORCE_EXECUTION)
+      if (hst->get_check_options() & CHECK_OPTION_FORCE_EXECUTION)
         continue;
 
       // does the last check "bump" into this one?
-      if ((last_check_time + last_check_exec_time) > tmp->run_time)
+      if ((last_check_time + last_check_exec_time) > (*it)->run_time)
         adjust_scheduling = true;
 
-      last_check_time = tmp->run_time;
+      last_check_time = (*it)->run_time;
 
       // calculate time needed to perform check.
       // NOTE: host check execution time is not taken into account,
@@ -93,19 +97,19 @@ void adjust_check_scheduling() {
       total_check_exec_time += last_check_exec_time;
     }
 
-    else if (tmp->event_type == EVENT_SERVICE_CHECK) {
-      if (!(svc = (service*)tmp->event_data))
+    else if ((*it)->event_type == EVENT_SERVICE_CHECK) {
+      if (!(svc = (com::centreon::engine::service*)(*it)->event_data))
         continue;
 
       // ignore forced checks.
-      if (svc->check_options & CHECK_OPTION_FORCE_EXECUTION)
+      if (svc->get_check_options() & CHECK_OPTION_FORCE_EXECUTION)
         continue;
 
       // does the last check "bump" into this one?
-      if ((last_check_time + last_check_exec_time) > tmp->run_time)
+      if ((last_check_time + last_check_exec_time) > (*it)->run_time)
         adjust_scheduling = true;
 
-      last_check_time = tmp->run_time;
+      last_check_time = (*it)->run_time;
 
       // calculate time needed to perform check.
       // NOTE: service check execution time is not taken into
@@ -138,34 +142,37 @@ void adjust_check_scheduling() {
 
   // adjust check scheduling.
   double current_icd_offset(inter_check_delay / 2.0);
-  for (timed_event* tmp(event_list_low); tmp; tmp = tmp->next) {
-
+  for (timed_event_list::iterator
+         it{timed_event::event_list_low.begin()},
+         end{timed_event::event_list_low.end()};
+       it != end;
+       ++it) {
     // skip events outside of our current window.
-    if (tmp->run_time <= first_window_time)
+    if ((*it)->run_time <= first_window_time)
       continue;
-    if (tmp->run_time > last_window_time)
+    if ((*it)->run_time > last_window_time)
       break;
 
-    if (tmp->event_type == EVENT_HOST_CHECK) {
+    if ((*it)->event_type == EVENT_HOST_CHECK) {
 
-      if (!(hst = (host*)tmp->event_data))
+      if (!(hst = (host*)(*it)->event_data))
         continue;
 
       // ignore forced checks.
-      if (hst->check_options & CHECK_OPTION_FORCE_EXECUTION)
+      if (hst->get_check_options() & CHECK_OPTION_FORCE_EXECUTION)
         continue;
 
       current_exec_time
-        = ((hst->execution_time
+        = ((hst->get_execution_time()
             + projected_host_check_overhead)
            * exec_time_factor);
     }
-    else if (tmp->event_type == EVENT_SERVICE_CHECK) {
-      if (!(svc = (service*)tmp->event_data))
+    else if ((*it)->event_type == EVENT_SERVICE_CHECK) {
+      if (!(svc = (com::centreon::engine::service*)(*it)->event_data))
         continue;
 
       // ignore forced checks.
-      if (svc->check_options & CHECK_OPTION_FORCE_EXECUTION)
+      if (svc->get_check_options() & CHECK_OPTION_FORCE_EXECUTION)
         continue;
 
       // NOTE: service check execution time is not taken into
@@ -182,15 +189,15 @@ void adjust_check_scheduling() {
              (time_t)(first_window_time
                       + (unsigned long)new_run_time_offset));
 
-    if (tmp->event_type == EVENT_HOST_CHECK) {
-      tmp->run_time = new_run_time;
-      hst->next_check = new_run_time;
-      update_host_status(hst, false);
+    if ((*it)->event_type == EVENT_HOST_CHECK) {
+      (*it)->run_time = new_run_time;
+      hst->set_next_check(new_run_time);
+      hst->update_status(false);
     }
     else {
-      tmp->run_time = new_run_time;
-      svc->next_check = new_run_time;
-      update_service_status(svc, false);
+      (*it)->run_time = new_run_time;
+      svc->set_next_check(new_run_time);
+      svc->update_status(false);
     }
 
     current_icd_offset += inter_check_delay;
@@ -199,7 +206,7 @@ void adjust_check_scheduling() {
 
   // resort event list (some events may be out of order at
   // this point).
-  resort_event_list(&event_list_low, &event_list_low_tail);
+  resort_event_list(timed_event::low);
   return;
 }
 
