@@ -38,25 +38,26 @@ host::setters const host::_setters[] = {
   { "check_period",                         SETTER(std::string const&, _set_check_period) },
   { "check_type",                           SETTER(int, _set_check_type) },
   { "current_attempt",                      SETTER(int, _set_current_attempt) },
-  { "current_event_id",                     SETTER(unsigned long, _set_current_event_id) },
-  { "current_notification_id",              SETTER(unsigned long, _set_current_notification_id) },
+  { "current_event_id",                     SETTER(uint64_t, _set_current_event_id) },
+  { "current_notification_id",              SETTER(uint64_t, _set_current_notification_id) },
   { "current_notification_number",          SETTER(int, _set_current_notification_number) },
-  { "current_problem_id",                   SETTER(unsigned long, _set_current_problem_id) },
+  { "current_problem_id",                   SETTER(uint64_t, _set_current_problem_id) },
   { "current_state",                        SETTER(int, _set_current_state) },
   { "event_handler",                        SETTER(std::string const&, _set_event_handler) },
   { "event_handler_enabled",                SETTER(bool, _set_event_handler_enabled) },
   { "failure_prediction_enabled",           SETTER(bool, _set_failure_prediction_enabled) },
   { "flap_detection_enabled",               SETTER(bool, _set_flap_detection_enabled) },
   { "has_been_checked",                     SETTER(bool, _set_has_been_checked) },
+  { "host_id",                              SETTER(uint64_t, _set_host_id) },
   { "host_name",                            SETTER(std::string const&, _set_host_name) },
   { "is_flapping",                          SETTER(bool, _set_is_flapping) },
   { "last_acknowledgement",                 SETTER(time_t, _set_last_acknowledgement) },
   { "last_check",                           SETTER(time_t, _set_last_check) },
-  { "last_event_id",                        SETTER(unsigned long, _set_last_event_id) },
+  { "last_event_id",                        SETTER(uint64_t, _set_last_event_id) },
   { "last_hard_state",                      SETTER(time_t, _set_last_hard_state) },
   { "last_hard_state_change",               SETTER(time_t, _set_last_hard_state_change) },
   { "last_notification",                    SETTER(time_t, _set_last_notification) },
-  { "last_problem_id",                      SETTER(unsigned long, _set_last_problem_id) },
+  { "last_problem_id",                      SETTER(uint64_t, _set_last_problem_id) },
   { "last_state",                           SETTER(time_t, _set_last_state) },
   { "last_state_change",                    SETTER(time_t, _set_last_state_change) },
   { "last_time_down",                       SETTER(time_t, _set_last_time_down) },
@@ -67,6 +68,12 @@ host::setters const host::_setters[] = {
   { "modified_attributes",                  SETTER(unsigned long, _set_modified_attributes) },
   { "next_check",                           SETTER(time_t, _set_next_check) },
   { "normal_check_interval",                SETTER(unsigned int, _set_normal_check_interval) },
+  { "notification_0",                       SETTER(std::string const&, _set_notification<0>) },
+  { "notification_1",                       SETTER(std::string const&, _set_notification<1>) },
+  { "notification_2",                       SETTER(std::string const&, _set_notification<2>) },
+  { "notification_3",                       SETTER(std::string const&, _set_notification<3>) },
+  { "notification_4",                       SETTER(std::string const&, _set_notification<4>) },
+  { "notification_5",                       SETTER(std::string const&, _set_notification<5>) },
   { "notification_period",                  SETTER(std::string const&, _set_notification_period) },
   { "notifications_enabled",                SETTER(bool, _set_notifications_enabled) },
   { "notified_on_down",                     SETTER(bool, _set_notified_on_down) },
@@ -78,7 +85,6 @@ host::setters const host::_setters[] = {
   { "plugin_output",                        SETTER(std::string const&, _set_plugin_output) },
   { "problem_has_been_acknowledged",        SETTER(bool, _set_problem_has_been_acknowledged) },
   { "process_performance_data",             SETTER(int, _set_process_performance_data) },
-  { "recovery_been_sent",                   SETTER(bool, _set_recovery_been_sent)},
   { "retry_check_interval",                 SETTER(unsigned int, _set_retry_check_interval) },
   { "state_history",                        SETTER(std::string const&, _set_state_history) },
   { "state_type",                           SETTER(int, _set_state_type) }
@@ -134,6 +140,7 @@ host& host::operator=(host const& right) {
     _event_handler_enabled = right._event_handler_enabled;
     _flap_detection_enabled = right._flap_detection_enabled;
     _has_been_checked = right._has_been_checked;
+    _host_id = right._host_id;
     _host_name = right._host_name;
     _is_flapping = right._is_flapping;
     _last_acknowledgement = right._last_acknowledgement;
@@ -164,12 +171,12 @@ host& host::operator=(host const& right) {
     _plugin_output = right._plugin_output;
     _problem_has_been_acknowledged = right._problem_has_been_acknowledged;
     _process_performance_data = right._process_performance_data;
-    _recovery_been_sent = right._recovery_been_sent;
     _retry_check_interval = right._retry_check_interval;
     _state_history = right._state_history;
     _state_type = right._state_type;
+    _notification = right._notification;
   }
-  return (*this);
+  return *this;
 }
 
 /**
@@ -201,6 +208,7 @@ bool host::operator==(host const& right) const throw () {
           && _event_handler_enabled == right._event_handler_enabled
           && _flap_detection_enabled == right._flap_detection_enabled
           && _has_been_checked == right._has_been_checked
+          && _host_id == right._host_id
           && _host_name == right._host_name
           && _is_flapping == right._is_flapping
           && _last_acknowledgement == right._last_acknowledgement
@@ -231,10 +239,10 @@ bool host::operator==(host const& right) const throw () {
           && _plugin_output == right._plugin_output
           && _problem_has_been_acknowledged == right._problem_has_been_acknowledged
           && _process_performance_data == right._process_performance_data
-          && _recovery_been_sent == right._recovery_been_sent
           && _retry_check_interval == right._retry_check_interval
           && _state_history == right._state_history
-          && _state_type == right._state_type);
+          && _state_type == right._state_type
+          && _notification == right._notification);
 }
 
 /**
@@ -245,7 +253,7 @@ bool host::operator==(host const& right) const throw () {
  *  @return True if is not the same object, otherwise false.
  */
 bool host::operator!=(host const& right) const throw () {
-  return (!operator==(right));
+  return !operator==(right);
 }
 
 /**
@@ -261,12 +269,12 @@ bool host::set(char const* key, char const* value) {
        i < sizeof(_setters) / sizeof(_setters[0]);
        ++i)
     if (!strcmp(_setters[i].name, key))
-      return ((_setters[i].func)(*this, value));
+      return (_setters[i].func)(*this, value);
   if ((key[0] == '_') && (strlen(value) > 3)) {
-    _customvariables[key + 1] = value + 2;
-    return (true);
+    _customvariables[key + 1] =  customvariable(value + 2);
+    return true;
   }
-  return (false);
+  return false;
 }
 
 /**
@@ -275,7 +283,7 @@ bool host::set(char const* key, char const* value) {
  *  @return The acknowledgement_type.
  */
 opt<int> const& host::acknowledgement_type() const throw () {
-  return (_acknowledgement_type);
+  return _acknowledgement_type;
 }
 
 /**
@@ -284,7 +292,7 @@ opt<int> const& host::acknowledgement_type() const throw () {
  *  @return The active_checks_enabled.
  */
 opt<bool> const& host::active_checks_enabled() const throw () {
-  return (_active_checks_enabled);
+  return _active_checks_enabled;
 }
 
 /**
@@ -293,7 +301,7 @@ opt<bool> const& host::active_checks_enabled() const throw () {
  *  @return The check_command.
  */
 opt<std::string> const& host::check_command() const throw () {
-  return (_check_command);
+  return _check_command;
 }
 
 /**
@@ -302,7 +310,7 @@ opt<std::string> const& host::check_command() const throw () {
  *  @return The check_execution_time.
  */
 opt<double> const& host::check_execution_time() const throw () {
-  return (_check_execution_time);
+  return _check_execution_time;
 }
 
 /**
@@ -311,7 +319,7 @@ opt<double> const& host::check_execution_time() const throw () {
  *  @return The check_flapping_recovery_notification.
  */
 opt<int> const& host::check_flapping_recovery_notification() const throw () {
-  return (_check_flapping_recovery_notification);
+  return _check_flapping_recovery_notification;
 }
 
 /**
@@ -320,7 +328,7 @@ opt<int> const& host::check_flapping_recovery_notification() const throw () {
  *  @return The check_latency.
  */
 opt<double> const& host::check_latency() const throw () {
-  return (_check_latency);
+  return _check_latency;
 }
 
 /**
@@ -329,7 +337,7 @@ opt<double> const& host::check_latency() const throw () {
  *  @return The check_options.
  */
 opt<int> const& host::check_options() const throw () {
-  return (_check_options);
+  return _check_options;
 }
 
 /**
@@ -338,7 +346,7 @@ opt<int> const& host::check_options() const throw () {
  *  @return The check_period.
  */
 opt<std::string> const& host::check_period() const throw () {
-  return (_check_period);
+  return _check_period;
 }
 
 /**
@@ -347,7 +355,7 @@ opt<std::string> const& host::check_period() const throw () {
  *  @return The check_type.
  */
 opt<int> const& host::check_type() const throw () {
-  return (_check_type);
+  return _check_type;
 }
 
 /**
@@ -356,7 +364,7 @@ opt<int> const& host::check_type() const throw () {
  *  @return The current_attempt.
  */
 opt<int> const& host::current_attempt() const throw () {
-  return (_current_attempt);
+  return _current_attempt;
 }
 
 /**
@@ -364,8 +372,8 @@ opt<int> const& host::current_attempt() const throw () {
  *
  *  @return The current_event_id.
  */
-opt<unsigned long> const& host::current_event_id() const throw () {
-  return (_current_event_id);
+opt<uint64_t> const& host::current_event_id() const throw () {
+  return _current_event_id;
 }
 
 /**
@@ -373,8 +381,8 @@ opt<unsigned long> const& host::current_event_id() const throw () {
  *
  *  @return The current_notification_id.
  */
-opt<unsigned long> const& host::current_notification_id() const throw () {
-  return (_current_notification_id);
+opt<uint64_t> const& host::current_notification_id() const throw () {
+  return _current_notification_id;
 }
 
 /**
@@ -383,7 +391,7 @@ opt<unsigned long> const& host::current_notification_id() const throw () {
  *  @return The current_notification_number.
  */
 opt<int> const& host::current_notification_number() const throw () {
-  return (_current_notification_number);
+  return _current_notification_number;
 }
 
 /**
@@ -391,8 +399,8 @@ opt<int> const& host::current_notification_number() const throw () {
  *
  *  @return The current_problem_id.
  */
-opt<unsigned long> const& host::current_problem_id() const throw () {
-  return (_current_problem_id);
+opt<uint64_t> const& host::current_problem_id() const throw () {
+  return _current_problem_id;
 }
 
 /**
@@ -401,7 +409,7 @@ opt<unsigned long> const& host::current_problem_id() const throw () {
  *  @return The current_state.
  */
 opt<int> const& host::current_state() const throw () {
-  return (_current_state);
+  return _current_state;
 }
 
 /**
@@ -410,7 +418,7 @@ opt<int> const& host::current_state() const throw () {
  *  @return The customvariables.
  */
 map_customvar const& host::customvariables() const throw () {
-  return (_customvariables);
+  return _customvariables;
 }
 
 /**
@@ -419,7 +427,7 @@ map_customvar const& host::customvariables() const throw () {
  *  @return The event_handler.
  */
 opt<std::string> const& host::event_handler() const throw () {
-  return (_event_handler);
+  return _event_handler;
 }
 
 /**
@@ -428,7 +436,7 @@ opt<std::string> const& host::event_handler() const throw () {
  *  @return The event_handler_enabled.
  */
 opt<bool> const& host::event_handler_enabled() const throw () {
-  return (_event_handler_enabled);
+  return _event_handler_enabled;
 }
 
 /**
@@ -437,7 +445,7 @@ opt<bool> const& host::event_handler_enabled() const throw () {
  *  @return The flap_detection_enabled.
  */
 opt<bool> const& host::flap_detection_enabled() const throw () {
-  return (_flap_detection_enabled);
+  return _flap_detection_enabled;
 }
 
 /**
@@ -446,7 +454,16 @@ opt<bool> const& host::flap_detection_enabled() const throw () {
  *  @return The has_been_checked.
  */
 opt<bool> const& host::has_been_checked() const throw () {
-  return (_has_been_checked);
+  return _has_been_checked;
+}
+
+/**
+ *  Get host_id.
+ *
+ *  @return The host_id.
+ */
+uint64_t host::host_id() const throw () {
+  return _host_id;
 }
 
 /**
@@ -455,7 +472,7 @@ opt<bool> const& host::has_been_checked() const throw () {
  *  @return The host_name.
  */
 std::string const& host::host_name() const throw () {
-  return (_host_name);
+  return _host_name;
 }
 
 /**
@@ -464,7 +481,7 @@ std::string const& host::host_name() const throw () {
  *  @return The is_flapping.
  */
 opt<bool> const& host::is_flapping() const throw () {
-  return (_is_flapping);
+  return _is_flapping;
 }
 
 /**
@@ -473,7 +490,7 @@ opt<bool> const& host::is_flapping() const throw () {
  *  @return The last acknowledgement.
  */
 opt<time_t> const& host::last_acknowledgement() const throw () {
-  return (_last_acknowledgement);
+  return _last_acknowledgement;
 }
 
 /**
@@ -482,7 +499,7 @@ opt<time_t> const& host::last_acknowledgement() const throw () {
  *  @return The last_check.
  */
 opt<time_t> const& host::last_check() const throw () {
-  return (_last_check);
+  return _last_check;
 }
 
 /**
@@ -490,8 +507,8 @@ opt<time_t> const& host::last_check() const throw () {
  *
  *  @return The last_event_id.
  */
-opt<unsigned long> const& host::last_event_id() const throw () {
-  return (_last_event_id);
+opt<uint64_t> const& host::last_event_id() const throw () {
+  return _last_event_id;
 }
 
 /**
@@ -500,7 +517,7 @@ opt<unsigned long> const& host::last_event_id() const throw () {
  *  @return The last_hard_state.
  */
 opt<time_t> const& host::last_hard_state() const throw () {
-  return (_last_hard_state);
+  return _last_hard_state;
 }
 
 /**
@@ -509,7 +526,7 @@ opt<time_t> const& host::last_hard_state() const throw () {
  *  @return The last_hard_state_change.
  */
 opt<time_t> const& host::last_hard_state_change() const throw () {
-  return (_last_hard_state_change);
+  return _last_hard_state_change;
 }
 
 /**
@@ -518,7 +535,7 @@ opt<time_t> const& host::last_hard_state_change() const throw () {
  *  @return The last_notification.
  */
 opt<time_t> const& host::last_notification() const throw () {
-  return (_last_notification);
+  return _last_notification;
 }
 
 /**
@@ -526,8 +543,8 @@ opt<time_t> const& host::last_notification() const throw () {
  *
  *  @return The last_problem_id.
  */
-opt<unsigned long> const& host::last_problem_id() const throw () {
-  return (_last_problem_id);
+opt<uint64_t> const& host::last_problem_id() const throw () {
+  return _last_problem_id;
 }
 
 /**
@@ -536,7 +553,7 @@ opt<unsigned long> const& host::last_problem_id() const throw () {
  *  @return The last_state.
  */
 opt<time_t> const& host::last_state() const throw () {
-  return (_last_state);
+  return _last_state;
 }
 
 /**
@@ -545,7 +562,7 @@ opt<time_t> const& host::last_state() const throw () {
  *  @return The last_state_change.
  */
 opt<time_t> const& host::last_state_change() const throw () {
-  return (_last_state_change);
+  return _last_state_change;
 }
 
 /**
@@ -554,7 +571,7 @@ opt<time_t> const& host::last_state_change() const throw () {
  *  @return The last_time_down.
  */
 opt<time_t> const& host::last_time_down() const throw () {
-  return (_last_time_down);
+  return _last_time_down;
 }
 
 /**
@@ -563,7 +580,7 @@ opt<time_t> const& host::last_time_down() const throw () {
  *  @return The last_time_unreachable.
  */
 opt<time_t> const& host::last_time_unreachable() const throw () {
-  return (_last_time_unreachable);
+  return _last_time_unreachable;
 }
 
 /**
@@ -572,7 +589,7 @@ opt<time_t> const& host::last_time_unreachable() const throw () {
  *  @return The last_time_up.
  */
 opt<time_t> const& host::last_time_up() const throw () {
-  return (_last_time_up);
+  return _last_time_up;
 }
 
 /**
@@ -581,7 +598,7 @@ opt<time_t> const& host::last_time_up() const throw () {
  *  @return The long_plugin_output.
  */
 opt<std::string> const& host::long_plugin_output() const throw () {
-  return (_long_plugin_output);
+  return _long_plugin_output;
 }
 
 /**
@@ -590,7 +607,7 @@ opt<std::string> const& host::long_plugin_output() const throw () {
  *  @return The max_attempts.
  */
 opt<unsigned int> const& host::max_attempts() const throw () {
-  return (_max_attempts);
+  return _max_attempts;
 }
 
 /**
@@ -599,7 +616,7 @@ opt<unsigned int> const& host::max_attempts() const throw () {
  *  @return The modified_attributes.
  */
 opt<unsigned long> const& host::modified_attributes() const throw () {
-  return (_modified_attributes);
+  return _modified_attributes;
 }
 
 /**
@@ -608,7 +625,7 @@ opt<unsigned long> const& host::modified_attributes() const throw () {
  *  @return The next_check.
  */
 opt<time_t> const& host::next_check() const throw () {
-  return (_next_check);
+  return _next_check;
 }
 
 /**
@@ -617,7 +634,7 @@ opt<time_t> const& host::next_check() const throw () {
  *  @return The normal_check_interval.
  */
 opt<unsigned int> const& host::normal_check_interval() const throw () {
-  return (_normal_check_interval);
+  return _normal_check_interval;
 }
 
 /**
@@ -626,7 +643,7 @@ opt<unsigned int> const& host::normal_check_interval() const throw () {
  *  @return The notification_period.
  */
 opt<std::string> const& host::notification_period() const throw () {
-  return (_notification_period);
+  return _notification_period;
 }
 
 /**
@@ -635,7 +652,7 @@ opt<std::string> const& host::notification_period() const throw () {
  *  @return The notifications_enabled.
  */
 opt<bool> const& host::notifications_enabled() const throw () {
-  return (_notifications_enabled);
+  return _notifications_enabled;
 }
 
 /**
@@ -644,7 +661,7 @@ opt<bool> const& host::notifications_enabled() const throw () {
  *  @return The notified_on_down.
  */
 opt<bool> const& host::notified_on_down() const throw () {
-  return (_notified_on_down);
+  return _notified_on_down;
 }
 
 /**
@@ -653,7 +670,7 @@ opt<bool> const& host::notified_on_down() const throw () {
  *  @return The notified_on_unreachable.
  */
 opt<bool> const& host::notified_on_unreachable() const throw () {
-  return (_notified_on_unreachable);
+  return _notified_on_unreachable;
 }
 
 /**
@@ -662,7 +679,7 @@ opt<bool> const& host::notified_on_unreachable() const throw () {
  *  @return The obsess_over_host.
  */
 opt<int> const& host::obsess_over_host() const throw () {
-  return (_obsess_over_host);
+  return _obsess_over_host;
 }
 
 /**
@@ -671,7 +688,7 @@ opt<int> const& host::obsess_over_host() const throw () {
  *  @return The passive_checks_enabled.
  */
 opt<bool> const& host::passive_checks_enabled() const throw () {
-  return (_passive_checks_enabled);
+  return _passive_checks_enabled;
 }
 
 /**
@@ -680,7 +697,7 @@ opt<bool> const& host::passive_checks_enabled() const throw () {
  *  @return The percent_state_change.
  */
 opt<double> const& host::percent_state_change() const throw () {
-  return (_percent_state_change);
+  return _percent_state_change;
 }
 
 /**
@@ -689,7 +706,7 @@ opt<double> const& host::percent_state_change() const throw () {
  *  @return The performance_data.
  */
 opt<std::string> const& host::performance_data() const throw () {
-  return (_performance_data);
+  return _performance_data;
 }
 
 /**
@@ -698,7 +715,7 @@ opt<std::string> const& host::performance_data() const throw () {
  *  @return The plugin_output.
  */
 opt<std::string> const& host::plugin_output() const throw () {
-  return (_plugin_output);
+  return _plugin_output;
 }
 
 /**
@@ -707,7 +724,7 @@ opt<std::string> const& host::plugin_output() const throw () {
  *  @return The problem_has_been_acknowledged.
  */
 opt<bool> const& host::problem_has_been_acknowledged() const throw () {
-  return (_problem_has_been_acknowledged);
+  return _problem_has_been_acknowledged;
 }
 
 /**
@@ -716,16 +733,7 @@ opt<bool> const& host::problem_has_been_acknowledged() const throw () {
  *  @return The process_performance_data.
  */
 opt<int> const& host::process_performance_data() const throw () {
-  return (_process_performance_data);
-}
-
-/**
- *  Get recovery_been_sent.
- *
- *  @return The recovery_been_sent.
- */
-opt<bool> const& host::recovery_been_sent() const throw () {
-  return (_recovery_been_sent);
+  return _process_performance_data;
 }
 
 /**
@@ -734,7 +742,7 @@ opt<bool> const& host::recovery_been_sent() const throw () {
  *  @return The retry_check_interval.
  */
 opt<unsigned int> const& host::retry_check_interval() const throw () {
-  return (_retry_check_interval);
+  return _retry_check_interval;
 }
 
 /**
@@ -743,7 +751,7 @@ opt<unsigned int> const& host::retry_check_interval() const throw () {
  *  @return The state_history.
  */
 opt<std::vector<int> > const& host::state_history() const throw () {
-  return (_state_history);
+  return _state_history;
 }
 
 /**
@@ -752,7 +760,7 @@ opt<std::vector<int> > const& host::state_history() const throw () {
  *  @return The state_type.
  */
 opt<int> const& host::state_type() const throw () {
-  return (_state_type);
+  return _state_type;
 }
 
 /**
@@ -762,7 +770,7 @@ opt<int> const& host::state_type() const throw () {
  */
 bool host::_set_acknowledgement_type(int value) {
   _acknowledgement_type = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -772,7 +780,7 @@ bool host::_set_acknowledgement_type(int value) {
  */
 bool host::_set_active_checks_enabled(bool value) {
   _active_checks_enabled = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -782,7 +790,7 @@ bool host::_set_active_checks_enabled(bool value) {
  */
 bool host::_set_check_command(std::string const& value) {
   _check_command = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -792,7 +800,7 @@ bool host::_set_check_command(std::string const& value) {
  */
 bool host::_set_check_execution_time(double value) {
   _check_execution_time = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -802,7 +810,7 @@ bool host::_set_check_execution_time(double value) {
  */
 bool host::_set_check_flapping_recovery_notification(int value) {
   _check_flapping_recovery_notification = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -812,7 +820,7 @@ bool host::_set_check_flapping_recovery_notification(int value) {
  */
 bool host::_set_check_latency(double value) {
   _check_latency = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -822,7 +830,7 @@ bool host::_set_check_latency(double value) {
  */
 bool host::_set_check_options(int value) {
   _check_options = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -832,7 +840,7 @@ bool host::_set_check_options(int value) {
  */
 bool host::_set_check_period(std::string const& value) {
   _check_period = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -842,7 +850,7 @@ bool host::_set_check_period(std::string const& value) {
  */
 bool host::_set_check_type(int value) {
   _check_type = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -852,7 +860,7 @@ bool host::_set_check_type(int value) {
  */
 bool host::_set_current_attempt(int value) {
   _current_attempt = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -860,9 +868,9 @@ bool host::_set_current_attempt(int value) {
  *
  *  @param[in] value The new current_event_id.
  */
-bool host::_set_current_event_id(unsigned long value) {
+bool host::_set_current_event_id(uint64_t value) {
   _current_event_id = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -870,9 +878,9 @@ bool host::_set_current_event_id(unsigned long value) {
  *
  *  @param[in] value The new current_notification_id.
  */
-bool host::_set_current_notification_id(unsigned long value) {
+bool host::_set_current_notification_id(uint64_t value) {
   _current_notification_id = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -882,7 +890,7 @@ bool host::_set_current_notification_id(unsigned long value) {
  */
 bool host::_set_current_notification_number(int value) {
   _current_notification_number = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -890,9 +898,9 @@ bool host::_set_current_notification_number(int value) {
  *
  *  @param[in] value The new current_problem_id.
  */
-bool host::_set_current_problem_id(unsigned long value) {
+bool host::_set_current_problem_id(uint64_t value) {
   _current_problem_id = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -902,7 +910,7 @@ bool host::_set_current_problem_id(unsigned long value) {
  */
 bool host::_set_current_state(int value) {
   _current_state = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -912,7 +920,7 @@ bool host::_set_current_state(int value) {
  */
 bool host::_set_event_handler(std::string const& value) {
   _event_handler = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -922,7 +930,7 @@ bool host::_set_event_handler(std::string const& value) {
  */
 bool host::_set_event_handler_enabled(bool value) {
   _event_handler_enabled = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -932,7 +940,7 @@ bool host::_set_event_handler_enabled(bool value) {
  */
 bool host::_set_failure_prediction_enabled(bool value) {
   (void)value;
-  return (true);
+  return true;
 }
 
 /**
@@ -942,7 +950,7 @@ bool host::_set_failure_prediction_enabled(bool value) {
  */
 bool host::_set_flap_detection_enabled(bool value) {
   _flap_detection_enabled = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -952,7 +960,17 @@ bool host::_set_flap_detection_enabled(bool value) {
  */
 bool host::_set_has_been_checked(bool value) {
   _has_been_checked = value;
-  return (true);
+  return true;
+}
+
+/**
+ *  Set host_id.
+ *
+ *  @param[in] value The new host_id.
+ */
+bool host::_set_host_id(uint64_t value) {
+  _host_id = value;
+  return true;
 }
 
 /**
@@ -962,7 +980,7 @@ bool host::_set_has_been_checked(bool value) {
  */
 bool host::_set_host_name(std::string const& value) {
   _host_name = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -972,7 +990,7 @@ bool host::_set_host_name(std::string const& value) {
  */
 bool host::_set_is_flapping(bool value) {
   _is_flapping = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -982,7 +1000,7 @@ bool host::_set_is_flapping(bool value) {
  */
 bool host::_set_last_acknowledgement(time_t value) {
   _last_acknowledgement = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -992,7 +1010,7 @@ bool host::_set_last_acknowledgement(time_t value) {
  */
 bool host::_set_last_check(time_t value) {
   _last_check = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1000,9 +1018,9 @@ bool host::_set_last_check(time_t value) {
  *
  *  @param[in] value The new last_event_id.
  */
-bool host::_set_last_event_id(unsigned long value) {
+bool host::_set_last_event_id(uint64_t value) {
   _last_event_id = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1012,7 +1030,7 @@ bool host::_set_last_event_id(unsigned long value) {
  */
 bool host::_set_last_hard_state(time_t value) {
   _last_hard_state = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1022,7 +1040,7 @@ bool host::_set_last_hard_state(time_t value) {
  */
 bool host::_set_last_hard_state_change(time_t value) {
   _last_hard_state_change = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1032,7 +1050,7 @@ bool host::_set_last_hard_state_change(time_t value) {
  */
 bool host::_set_last_notification(time_t value) {
   _last_notification = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1040,9 +1058,9 @@ bool host::_set_last_notification(time_t value) {
  *
  *  @param[in] value The new last_problem_id.
  */
-bool host::_set_last_problem_id(unsigned long value) {
+bool host::_set_last_problem_id(uint64_t value) {
   _last_problem_id = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1052,7 +1070,7 @@ bool host::_set_last_problem_id(unsigned long value) {
  */
 bool host::_set_last_state(time_t value) {
   _last_state = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1062,7 +1080,7 @@ bool host::_set_last_state(time_t value) {
  */
 bool host::_set_last_state_change(time_t value) {
   _last_state_change = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1072,7 +1090,7 @@ bool host::_set_last_state_change(time_t value) {
  */
 bool host::_set_last_time_down(time_t value) {
   _last_time_down = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1082,7 +1100,7 @@ bool host::_set_last_time_down(time_t value) {
  */
 bool host::_set_last_time_unreachable(time_t value) {
   _last_time_unreachable = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1092,7 +1110,7 @@ bool host::_set_last_time_unreachable(time_t value) {
  */
 bool host::_set_last_time_up(time_t value) {
   _last_time_up = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1102,7 +1120,7 @@ bool host::_set_last_time_up(time_t value) {
  */
 bool host::_set_long_plugin_output(std::string const& value) {
   _long_plugin_output = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1113,9 +1131,9 @@ bool host::_set_long_plugin_output(std::string const& value) {
 bool host::_set_max_attempts(unsigned int value) {
   if (value) {
     _max_attempts = value;
-    return (true);
+    return true;
   }
-  return (false);
+  return false;
 }
 
 /**
@@ -1125,7 +1143,7 @@ bool host::_set_max_attempts(unsigned int value) {
  */
 bool host::_set_modified_attributes(unsigned long value) {
   _modified_attributes = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1135,7 +1153,7 @@ bool host::_set_modified_attributes(unsigned long value) {
  */
 bool host::_set_next_check(time_t value) {
   _next_check = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1145,7 +1163,7 @@ bool host::_set_next_check(time_t value) {
  */
 bool host::_set_normal_check_interval(unsigned int value) {
   _normal_check_interval = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1155,7 +1173,7 @@ bool host::_set_normal_check_interval(unsigned int value) {
  */
 bool host::_set_notification_period(std::string const& value) {
   _notification_period = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1165,7 +1183,18 @@ bool host::_set_notification_period(std::string const& value) {
  */
 bool host::_set_notifications_enabled(bool value) {
   _notifications_enabled = value;
-  return (true);
+  return true;
+}
+
+bool host::has_notifications() const {
+  for (auto const& n : _notification)
+    if (!n.empty())
+      return true;
+  return false;
+}
+
+std::array<std::string, 6> host::notifications() const noexcept{
+  return _notification;
 }
 
 /**
@@ -1175,7 +1204,7 @@ bool host::_set_notifications_enabled(bool value) {
  */
 bool host::_set_notified_on_down(bool value) {
   _notified_on_down = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1185,7 +1214,7 @@ bool host::_set_notified_on_down(bool value) {
  */
 bool host::_set_notified_on_unreachable(bool value) {
   _notified_on_unreachable = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1195,7 +1224,7 @@ bool host::_set_notified_on_unreachable(bool value) {
  */
 bool host::_set_obsess_over_host(int value) {
   _obsess_over_host = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1205,7 +1234,7 @@ bool host::_set_obsess_over_host(int value) {
  */
 bool host::_set_passive_checks_enabled(bool value) {
   _passive_checks_enabled = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1215,7 +1244,7 @@ bool host::_set_passive_checks_enabled(bool value) {
  */
 bool host::_set_percent_state_change(double value) {
   _percent_state_change = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1225,7 +1254,7 @@ bool host::_set_percent_state_change(double value) {
  */
 bool host::_set_performance_data(std::string const& value) {
   _performance_data = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1235,7 +1264,7 @@ bool host::_set_performance_data(std::string const& value) {
  */
 bool host::_set_plugin_output(std::string const& value) {
   _plugin_output = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1245,7 +1274,7 @@ bool host::_set_plugin_output(std::string const& value) {
  */
 bool host::_set_problem_has_been_acknowledged(bool value) {
   _problem_has_been_acknowledged = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1255,20 +1284,9 @@ bool host::_set_problem_has_been_acknowledged(bool value) {
  */
 bool host::_set_process_performance_data(int value) {
   _process_performance_data = value;
-  return (true);
+  return true;
 }
 
-/**
- *  Set _set_recovery_been_sent.
- *
- *  @param[in] value The new _set_recovery_been_sent.
- */
-bool host::_set_recovery_been_sent(bool value) {
-  _recovery_been_sent = value;
-  return (true);
-}
-
-
 /**
  *  Set retry_check_interval.
  *
@@ -1276,7 +1294,7 @@ bool host::_set_recovery_been_sent(bool value) {
  */
 bool host::_set_retry_check_interval(unsigned int value) {
   _retry_check_interval = value;
-  return (true);
+  return true;
 }
 
 /**
@@ -1296,12 +1314,12 @@ bool host::_set_state_history(std::string const& value) {
     int state(0);
     if (!string::to(it->c_str(), state)) {
       _state_history.reset();
-      return (false);
+      return false;
     }
     state_history.push_back(state);
   }
   _state_history.set(state_history);
-  return (true);
+  return true;
 }
 
 /**
@@ -1311,5 +1329,5 @@ bool host::_set_state_history(std::string const& value) {
  */
 bool host::_set_state_type(int value) {
   _state_type = value;
-  return (true);
+  return true;
 }
