@@ -20,126 +20,29 @@
 
 #include <sstream>
 #include "com/centreon/engine/broker.hh"
+#include "com/centreon/engine/comment.hh"
+#include "com/centreon/engine/downtimes/downtime.hh"
+#include "com/centreon/engine/downtimes/downtime_manager.hh"
 #include "com/centreon/engine/globals.hh"
 #include "com/centreon/engine/logging.hh"
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/macros.hh"
 #include "com/centreon/engine/neberrors.hh"
-#include "com/centreon/engine/notifications.hh"
-#include "com/centreon/engine/objects/comment.hh"
-#include "com/centreon/engine/objects/downtime.hh"
-#include "com/centreon/engine/perfdata.hh"
 #include "com/centreon/engine/sehandlers.hh"
 #include "com/centreon/engine/utils.hh"
 
+using namespace com::centreon::engine;
+using namespace com::centreon::engine::downtimes;
 using namespace com::centreon::engine::logging;
 
 /******************************************************************/
 /************* OBSESSIVE COMPULSIVE HANDLER FUNCTIONS *************/
 /******************************************************************/
 
-/* handles service check results in an obsessive compulsive manner... */
-int obsessive_compulsive_service_check_processor(service* svc) {
-  char* raw_command = NULL;
-  char* processed_command = NULL;
-  host* temp_host = NULL;
-  int early_timeout = false;
-  double exectime = 0.0;
-  int macro_options = STRIP_ILLEGAL_MACRO_CHARS | ESCAPE_MACRO_CHARS;
-  nagios_macros mac;
-
-  logger(dbg_functions, basic)
-    << "obsessive_compulsive_service_check_processor()";
-
-  if (svc == NULL)
-    return (ERROR);
-
-  /* bail out if we shouldn't be obsessing */
-  if (config->obsess_over_services() == false)
-    return (OK);
-  if (svc->obsess_over_service == false)
-    return (OK);
-
-  /* if there is no valid command, exit */
-  if (config->ocsp_command().empty())
-    return (ERROR);
-
-  /* find the associated host */
-  if ((temp_host = (host*) svc->host_ptr) == NULL)
-    return (ERROR);
-
-  /* update service macros */
-  memset(&mac, 0, sizeof(mac));
-  grab_host_macros_r(&mac, temp_host);
-  grab_service_macros_r(&mac, svc);
-
-  /* get the raw command line */
-  get_raw_command_line_r(
-    &mac,
-    ocsp_command_ptr,
-    config->ocsp_command().c_str(),
-    &raw_command, macro_options);
-  if (raw_command == NULL) {
-    clear_volatile_macros_r(&mac);
-    return (ERROR);
-  }
-
-  logger(dbg_checks, most)
-    << "Raw obsessive compulsive service processor "
-    "command line: " << raw_command;
-
-  /* process any macros in the raw command line */
-  process_macros_r(
-    &mac,
-    raw_command,
-    &processed_command,
-    macro_options);
-  if (processed_command == NULL) {
-    clear_volatile_macros_r(&mac);
-    return (ERROR);
-  }
-
-  logger(dbg_checks, most)
-    << "Processed obsessive compulsive service "
-    "processor command line: " << processed_command;
-
-  /* run the command */
-  try {
-      my_system_r(
-      &mac,
-      processed_command,
-      config->ocsp_timeout(),
-      &early_timeout,
-      &exectime,
-      NULL,
-      0);
-  } catch (std::exception const& e) {
-    logger(log_runtime_error, basic)
-      << "Error: can't execute compulsive service processor command line '"
-      << processed_command << "' : " << e.what();
-  }
-
-  clear_volatile_macros_r(&mac);
-
-  /* check to see if the command timed out */
-  if (early_timeout == true)
-    logger(log_runtime_warning, basic)
-      << "Warning: OCSP command '" << processed_command
-      << "' for service '" << svc->description << "' on host '"
-      << svc->host_name << "' timed out after "
-      << config->ocsp_timeout() << " seconds";
-
-  /* free memory */
-  delete[] raw_command;
-  delete[] processed_command;
-
-  return (OK);
-}
-
 /* handles host check results in an obsessive compulsive manner... */
-int obsessive_compulsive_host_check_processor(host* hst) {
-  char* raw_command = NULL;
-  char* processed_command = NULL;
+int obsessive_compulsive_host_check_processor(com::centreon::engine::host* hst) {
+  std::string raw_command;
+  std::string processed_command;
   int early_timeout = false;
   double exectime = 0.0;
   int macro_options = STRIP_ILLEGAL_MACRO_CHARS | ESCAPE_MACRO_CHARS;
@@ -148,21 +51,20 @@ int obsessive_compulsive_host_check_processor(host* hst) {
   logger(dbg_functions, basic)
     << "obsessive_compulsive_host_check_processor()";
 
-  if (hst == NULL)
-    return (ERROR);
+  if (hst == nullptr)
+    return ERROR;
 
   /* bail out if we shouldn't be obsessing */
-  if (config->obsess_over_hosts() == false)
-    return (OK);
-  if (hst->obsess_over_host == false)
-    return (OK);
+  if (!config->obsess_over_hosts())
+    return OK;
+  if (!hst->get_obsess_over())
+    return OK;
 
   /* if there is no valid command, exit */
   if (config->ochp_command().empty())
-    return (ERROR);
+    return ERROR;
 
   /* update macros */
-  memset(&mac, 0, sizeof(mac));
   grab_host_macros_r(&mac, hst);
 
   /* get the raw command line */
@@ -170,10 +72,10 @@ int obsessive_compulsive_host_check_processor(host* hst) {
     &mac,
     ochp_command_ptr,
     config->ochp_command().c_str(),
-    &raw_command, macro_options);
-  if (raw_command == NULL) {
+    raw_command, macro_options);
+  if (raw_command.empty()) {
     clear_volatile_macros_r(&mac);
-    return (ERROR);
+    return ERROR;
   }
 
   logger(dbg_checks, most)
@@ -184,11 +86,11 @@ int obsessive_compulsive_host_check_processor(host* hst) {
   process_macros_r(
     &mac,
     raw_command,
-    &processed_command,
+    processed_command,
     macro_options);
-  if (processed_command == NULL) {
+  if (processed_command.empty()) {
     clear_volatile_macros_r(&mac);
-    return (ERROR);
+    return ERROR;
   }
 
   logger(dbg_checks, most)
@@ -197,13 +99,14 @@ int obsessive_compulsive_host_check_processor(host* hst) {
 
   /* run the command */
   try {
+    std::string tmp;
     my_system_r(
       &mac,
       processed_command,
       config->ochp_timeout(),
       &early_timeout,
       &exectime,
-      NULL,
+      tmp,
       0);
   } catch (std::exception const& e) {
     logger(log_runtime_error, basic)
@@ -216,87 +119,22 @@ int obsessive_compulsive_host_check_processor(host* hst) {
   if (early_timeout == true)
     logger(log_runtime_warning, basic)
       << "Warning: OCHP command '" << processed_command
-      << "' for host '" << hst->name << "' timed out after "
+      << "' for host '" << hst->get_name() << "' timed out after "
       << config->ochp_timeout() << " seconds";
 
-  /* free memory */
-  delete[] raw_command;
-  delete[] processed_command;
-
-  return (OK);
+  return OK;
 }
 
 /******************************************************************/
 /**************** SERVICE EVENT HANDLER FUNCTIONS *****************/
 /******************************************************************/
 
-/* handles changes in the state of a service */
-int handle_service_event(service* svc) {
-  host* temp_host = NULL;
-  nagios_macros mac;
-
-  logger(dbg_functions, basic)
-    << "handle_service_event()";
-
-  if (svc == NULL)
-    return (ERROR);
-
-  /* send event data to broker */
-  broker_statechange_data(
-    NEBTYPE_STATECHANGE_END,
-    NEBFLAG_NONE,
-    NEBATTR_NONE,
-    SERVICE_STATECHANGE,
-    (void*)svc,
-    svc->current_state,
-    svc->state_type,
-    svc->current_attempt,
-    svc->max_attempts,
-    NULL);
-
-  /* bail out if we shouldn't be running event handlers */
-  if (config->enable_event_handlers() == false)
-    return (OK);
-  if (svc->event_handler_enabled == false)
-    return (OK);
-
-  /* find the host */
-  if ((temp_host = (host*)svc->host_ptr) == NULL)
-    return (ERROR);
-
-  /* update service macros */
-  memset(&mac, 0, sizeof(mac));
-  grab_host_macros_r(&mac, temp_host);
-  grab_service_macros_r(&mac, svc);
-
-  /* run the global service event handler */
-  run_global_service_event_handler(&mac, svc);
-
-  /* run the event handler command if there is one */
-  if (svc->event_handler != NULL)
-    run_service_event_handler(&mac, svc);
-  clear_volatile_macros_r(&mac);
-
-  /* send data to event broker */
-  broker_external_command(
-    NEBTYPE_EXTERNALCOMMAND_CHECK,
-    NEBFLAG_NONE,
-    NEBATTR_NONE,
-    CMD_NONE,
-    time(NULL),
-    NULL,
-    NULL,
-    NULL);
-
-  return (OK);
-}
-
 /* runs the global service event handler */
-int run_global_service_event_handler(nagios_macros* mac, service* svc) {
-  char* raw_command = NULL;
-  char* processed_command = NULL;
-  char* processed_logentry = NULL;
-  char* command_output = NULL;
+int run_global_service_event_handler(nagios_macros* mac, com::centreon::engine::service* svc) {
+  std::string raw_command;
+  std::string processed_command;
+  std::string processed_logentry;
+  std::string command_output;
   int early_timeout = false;
   double exectime = 0.0;
   int result = 0;
@@ -308,42 +146,42 @@ int run_global_service_event_handler(nagios_macros* mac, service* svc) {
   logger(dbg_functions, basic)
     << "run_global_service_event_handler()";
 
-  if (svc == NULL)
-    return (ERROR);
+  if (svc == nullptr)
+    return ERROR;
 
   /* bail out if we shouldn't be running event handlers */
   if (config->enable_event_handlers() == false)
-    return (OK);
+    return OK;
 
   /* a global service event handler command has not been defined */
   if (config->global_service_event_handler().empty())
-    return (ERROR);
+    return ERROR;
 
   logger(dbg_eventhandlers, more)
     << "Running global event handler for service '"
-    << svc->description << "' on host '" << svc->host_name << "'...";
+    << svc->get_description() << "' on host '" << svc->get_hostname() << "'...";
 
   /* get start time */
-  gettimeofday(&start_time, NULL);
+  gettimeofday(&start_time, nullptr);
 
   /* get the raw command line */
   get_raw_command_line_r(
     mac,
     global_service_event_handler_ptr,
     config->global_service_event_handler().c_str(),
-    &raw_command,
+    raw_command,
     macro_options);
-  if (raw_command == NULL) {
-    return (ERROR);
+  if (raw_command.empty()) {
+    return ERROR;
   }
 
   logger(dbg_eventhandlers, most)
     << "Raw global service event handler command line: " << raw_command;
 
   /* process any macros in the raw command line */
-  process_macros_r(mac, raw_command, &processed_command, macro_options);
-  if (processed_command == NULL)
-    return (ERROR);
+  process_macros_r(mac, raw_command, processed_command, macro_options);
+  if (processed_command.empty())
+    return ERROR;
 
   logger(dbg_eventhandlers, most)
     << "Processed global service event handler "
@@ -351,14 +189,14 @@ int run_global_service_event_handler(nagios_macros* mac, service* svc) {
 
   if (config->log_event_handlers() == true) {
     std::ostringstream oss;
-    oss << "GLOBAL SERVICE EVENT HANDLER: " << svc->host_name << ';'
-	<< svc->description
+    oss << "GLOBAL SERVICE EVENT HANDLER: " << svc->get_hostname() << ';'
+	<< svc->get_description()
         << ";$SERVICESTATE$;$SERVICESTATETYPE$;$SERVICEATTEMPT$;"
         << config->global_service_event_handler();
     process_macros_r(
       mac,
-      oss.str().c_str(),
-      &processed_logentry,
+      oss.str(),
+      processed_logentry,
       macro_options);
     logger(log_event_handler, basic)
       << processed_logentry;
@@ -373,8 +211,8 @@ int run_global_service_event_handler(nagios_macros* mac, service* svc) {
     NEBATTR_NONE,
     GLOBAL_SERVICE_EVENTHANDLER,
     (void*)svc,
-    svc->current_state,
-    svc->state_type,
+    svc->get_current_state(),
+    svc->get_state_type(),
     start_time,
     end_time,
     exectime,
@@ -382,17 +220,14 @@ int run_global_service_event_handler(nagios_macros* mac, service* svc) {
     early_timeout,
     result,
     config->global_service_event_handler().c_str(),
-    processed_command,
-    NULL,
-    NULL);
+    const_cast<char*>(processed_command.c_str()),
+    nullptr,
+    nullptr);
 
   /* neb module wants to override (or cancel) the event handler - perhaps it will run the eventhandler itself */
   if ((neb_result == NEBERROR_CALLBACKCANCEL)
       || (neb_result == NEBERROR_CALLBACKOVERRIDE)) {
-    delete[] processed_command;
-    delete[] raw_command;
-    delete[] processed_logentry;
-    return ((neb_result == NEBERROR_CALLBACKCANCEL) ? ERROR : OK);
+    return (neb_result == NEBERROR_CALLBACKCANCEL) ? ERROR : OK;
   }
 
   /* run the command */
@@ -403,7 +238,7 @@ int run_global_service_event_handler(nagios_macros* mac, service* svc) {
                config->event_handler_timeout(),
                &early_timeout,
                &exectime,
-               &command_output,
+               command_output,
                0);
   } catch (std::exception const& e) {
     logger(log_runtime_error, basic)
@@ -420,7 +255,7 @@ int run_global_service_event_handler(nagios_macros* mac, service* svc) {
       << config->event_handler_timeout() << " seconds";
 
   /* get end time */
-  gettimeofday(&end_time, NULL);
+  gettimeofday(&end_time, nullptr);
 
   /* send event data to broker */
   broker_event_handler(
@@ -429,8 +264,8 @@ int run_global_service_event_handler(nagios_macros* mac, service* svc) {
     NEBATTR_NONE,
     GLOBAL_SERVICE_EVENTHANDLER,
     (void*)svc,
-    svc->current_state,
-    svc->state_type,
+    svc->get_current_state(),
+    svc->get_state_type(),
     start_time,
     end_time,
     exectime,
@@ -438,25 +273,19 @@ int run_global_service_event_handler(nagios_macros* mac, service* svc) {
     early_timeout,
     result,
     config->global_service_event_handler().c_str(),
-    processed_command,
-    command_output,
-    NULL);
+    const_cast<char *>(processed_command.c_str()),
+    const_cast<char *>(command_output.c_str()),
+    nullptr);
 
-  /* free memory */
-  delete[] command_output;
-  delete[] raw_command;
-  delete[] processed_command;
-  delete[] processed_logentry;
-
-  return (OK);
+  return OK;
 }
 
 /* runs a service event handler command */
-int run_service_event_handler(nagios_macros* mac, service* svc) {
-  char* raw_command = NULL;
-  char* processed_command = NULL;
-  char* processed_logentry = NULL;
-  char* command_output = NULL;
+int run_service_event_handler(nagios_macros* mac, com::centreon::engine::service* svc) {
+  std::string raw_command;
+  std::string processed_command;
+  std::string processed_logentry;
+  std::string command_output;
   int early_timeout = false;
   double exectime = 0.0;
   int result = 0;
@@ -469,29 +298,29 @@ int run_service_event_handler(nagios_macros* mac, service* svc) {
   logger(dbg_functions, basic)
     << "run_service_event_handler()";
 
-  if (svc == NULL)
-    return (ERROR);
+  if (svc == nullptr)
+    return ERROR;
 
   /* bail if there's no command */
-  if (svc->event_handler == NULL)
-    return (ERROR);
+  if (svc->get_event_handler().empty())
+    return ERROR;
 
   logger(dbg_eventhandlers, more)
-    << "Running event handler for service '" << svc->description
-    << "' on host '" << svc->host_name <<"'...";
+    << "Running event handler for service '" << svc->get_description()
+    << "' on host '" << svc->get_hostname() <<"'...";
 
   /* get start time */
-  gettimeofday(&start_time, NULL);
+  gettimeofday(&start_time, nullptr);
 
   /* get the raw command line */
   get_raw_command_line_r(
     mac,
-    svc->event_handler_ptr,
-    svc->event_handler,
-    &raw_command,
+    svc->get_event_handler_ptr(),
+    svc->get_event_handler().c_str(),
+    raw_command,
     macro_options);
-  if (raw_command == NULL)
-    return (ERROR);
+  if (raw_command.empty())
+    return ERROR;
 
   logger(dbg_eventhandlers, most)
     << "Raw service event handler command line: " << raw_command;
@@ -500,10 +329,10 @@ int run_service_event_handler(nagios_macros* mac, service* svc) {
   process_macros_r(
     mac,
     raw_command,
-    &processed_command,
+    processed_command,
     macro_options);
-  if (processed_command == NULL)
-    return (ERROR);
+  if (processed_command.empty())
+    return ERROR;
 
   logger(dbg_eventhandlers, most)
     << "Processed service event handler command line: "
@@ -511,14 +340,14 @@ int run_service_event_handler(nagios_macros* mac, service* svc) {
 
   if (config->log_event_handlers() == true) {
     std::ostringstream oss;
-    oss << "SERVICE EVENT HANDLER: " << svc->host_name << ';'
-	<< svc->description
+    oss << "SERVICE EVENT HANDLER: " << svc->get_hostname() << ';'
+	<< svc->get_description()
 	<< ";$SERVICESTATE$;$SERVICESTATETYPE$;$SERVICEATTEMPT$;"
-	<< svc->event_handler;
+	<< svc->get_event_handler();
     process_macros_r(
       mac,
-      oss.str().c_str(),
-      &processed_logentry,
+      oss.str(),
+      processed_logentry,
       macro_options);
     logger(log_event_handler, basic)
       << processed_logentry;
@@ -533,26 +362,23 @@ int run_service_event_handler(nagios_macros* mac, service* svc) {
                  NEBATTR_NONE,
                  SERVICE_EVENTHANDLER,
                  (void*)svc,
-                 svc->current_state,
-                 svc->state_type,
+                 svc->get_current_state(),
+                 svc->get_state_type(),
                  start_time,
                  end_time,
                  exectime,
                  config->event_handler_timeout(),
                  early_timeout,
                  result,
-                 svc->event_handler,
-                 processed_command,
-                 NULL,
-                 NULL);
+                 svc->get_event_handler().c_str(),
+                 const_cast<char *>(processed_command.c_str()),
+                 nullptr,
+                 nullptr);
 
   /* neb module wants to override (or cancel) the event handler - perhaps it will run the eventhandler itself */
   if ((neb_result == NEBERROR_CALLBACKCANCEL)
       || (neb_result == NEBERROR_CALLBACKOVERRIDE)) {
-    delete[] processed_command;
-    delete[] raw_command;
-    delete[] processed_logentry;
-    return ((neb_result == NEBERROR_CALLBACKCANCEL) ? ERROR : OK);
+    return (neb_result == NEBERROR_CALLBACKCANCEL) ? ERROR : OK;
   }
 
   /* run the command */
@@ -563,7 +389,7 @@ int run_service_event_handler(nagios_macros* mac, service* svc) {
                config->event_handler_timeout(),
                &early_timeout,
                &exectime,
-               &command_output,
+               command_output,
                0);
   } catch (std::exception const& e) {
     logger(log_runtime_error, basic)
@@ -579,7 +405,7 @@ int run_service_event_handler(nagios_macros* mac, service* svc) {
       << " seconds";
 
   /* get end time */
-  gettimeofday(&end_time, NULL);
+  gettimeofday(&end_time, nullptr);
 
   /* send event data to broker */
   broker_event_handler(
@@ -588,26 +414,20 @@ int run_service_event_handler(nagios_macros* mac, service* svc) {
     NEBATTR_NONE,
     SERVICE_EVENTHANDLER,
     (void*)svc,
-    svc->current_state,
-    svc->state_type,
+    svc->get_current_state(),
+    svc->get_state_type(),
     start_time,
     end_time,
     exectime,
     config->event_handler_timeout(),
     early_timeout,
     result,
-    svc->event_handler,
-    processed_command,
-    command_output,
-    NULL);
+    svc->get_event_handler().c_str(),
+    const_cast<char *>(processed_command.c_str()),
+    const_cast<char *>(command_output.c_str()),
+    nullptr);
 
-  /* free memory */
-  delete[] command_output;
-  delete[] raw_command;
-  delete[] processed_command;
-  delete[] processed_logentry;
-
-  return (OK);
+  return OK;
 }
 
 /******************************************************************/
@@ -615,14 +435,14 @@ int run_service_event_handler(nagios_macros* mac, service* svc) {
 /******************************************************************/
 
 /* handles a change in the status of a host */
-int handle_host_event(host* hst) {
+int handle_host_event(com::centreon::engine::host* hst) {
   nagios_macros mac;
 
   logger(dbg_functions, basic)
     << "handle_host_event()";
 
-  if (hst == NULL)
-    return (ERROR);
+  if (hst == nullptr)
+    return ERROR;
 
   /* send event data to broker */
   broker_statechange_data(
@@ -631,27 +451,26 @@ int handle_host_event(host* hst) {
     NEBATTR_NONE,
     HOST_STATECHANGE,
     (void*)hst,
-    hst->current_state,
-    hst->state_type,
-    hst->current_attempt,
-    hst->max_attempts,
-    NULL);
+    hst->get_current_state(),
+    hst->get_state_type(),
+    hst->get_current_attempt(),
+    hst->get_max_attempts(),
+    nullptr);
 
   /* bail out if we shouldn't be running event handlers */
-  if (config->enable_event_handlers() == false)
-    return (OK);
-  if (hst->event_handler_enabled == false)
-    return (OK);
+  if (!config->enable_event_handlers())
+    return OK;
+  if (!hst->get_event_handler_enabled())
+    return OK;
 
   /* update host macros */
-  memset(&mac, 0, sizeof(mac));
   grab_host_macros_r(&mac, hst);
 
   /* run the global host event handler */
   run_global_host_event_handler(&mac, hst);
 
   /* run the event handler command if there is one */
-  if (hst->event_handler != NULL)
+  if (!hst->get_event_handler().empty())
     run_host_event_handler(&mac, hst);
 
   /* send data to event broker */
@@ -660,20 +479,21 @@ int handle_host_event(host* hst) {
     NEBFLAG_NONE,
     NEBATTR_NONE,
     CMD_NONE,
-    time(NULL),
-    NULL,
-    NULL,
-    NULL);
+    time(nullptr),
+    nullptr,
+    nullptr,
+    nullptr);
 
-  return (OK);
+  return OK;
 }
 
 /* runs the global host event handler */
-int run_global_host_event_handler(nagios_macros* mac, host* hst) {
-  char* raw_command = NULL;
-  char* processed_command = NULL;
-  char* processed_logentry = NULL;
-  char* command_output = NULL;
+int run_global_host_event_handler(nagios_macros* mac,
+                                  com::centreon::engine::host* hst) {
+  std::string raw_command;
+  std::string processed_command;
+  std::string processed_logentry;
+  std::string command_output;
   int early_timeout = false;
   double exectime = 0.0;
   int result = 0;
@@ -685,32 +505,32 @@ int run_global_host_event_handler(nagios_macros* mac, host* hst) {
   logger(dbg_functions, basic)
     << "run_global_host_event_handler()";
 
-  if (hst == NULL)
-    return (ERROR);
+  if (hst == nullptr)
+    return ERROR;
 
   /* bail out if we shouldn't be running event handlers */
   if (config->enable_event_handlers() == false)
-    return (OK);
+    return OK;
 
   /* no global host event handler command is defined */
   if (config->global_host_event_handler() == "")
-    return (ERROR);
+    return ERROR;
 
   logger(dbg_eventhandlers, more)
-    << "Running global event handler for host '" << hst->name << "'...";
+    << "Running global event handler for host '" << hst->get_name() << "'...";
 
   /* get start time */
-  gettimeofday(&start_time, NULL);
+  gettimeofday(&start_time, nullptr);
 
   /* get the raw command line */
   get_raw_command_line_r(
     mac,
     global_host_event_handler_ptr,
     config->global_host_event_handler().c_str(),
-    &raw_command,
+    raw_command,
     macro_options);
-  if (raw_command == NULL)
-    return (ERROR);
+  if (raw_command.empty())
+    return ERROR;
 
   logger(dbg_eventhandlers, most)
     << "Raw global host event handler command line: " << raw_command;
@@ -719,10 +539,10 @@ int run_global_host_event_handler(nagios_macros* mac, host* hst) {
   process_macros_r(
     mac,
     raw_command,
-    &processed_command,
+    processed_command,
     macro_options);
-  if (processed_command == NULL)
-    return (ERROR);
+  if (processed_command.empty())
+    return ERROR;
 
   logger(dbg_eventhandlers, most)
     << "Processed global host event handler "
@@ -730,13 +550,13 @@ int run_global_host_event_handler(nagios_macros* mac, host* hst) {
 
   if (config->log_event_handlers() == true) {
     std::ostringstream oss;
-    oss << "GLOBAL HOST EVENT HANDLER: " << hst->name
+    oss << "GLOBAL HOST EVENT HANDLER: " << hst->get_name()
 	<< "$HOSTSTATE$;$HOSTSTATETYPE$;$HOSTATTEMPT$;"
 	<< config->global_host_event_handler();
     process_macros_r(
       mac,
-      oss.str().c_str(),
-      &processed_logentry,
+      oss.str(),
+      processed_logentry,
       macro_options);
     logger(log_event_handler, basic)
       << processed_logentry;
@@ -751,25 +571,22 @@ int run_global_host_event_handler(nagios_macros* mac, host* hst) {
                  NEBATTR_NONE,
                  GLOBAL_HOST_EVENTHANDLER,
                  (void*)hst,
-                 hst->current_state,
-                 hst->state_type,
+                 hst->get_current_state(),
+                 hst->get_state_type(),
                  start_time,
                  end_time,
                  exectime,
                  config->event_handler_timeout(),
                  early_timeout, result,
                  config->global_host_event_handler().c_str(),
-                 processed_command,
-                 NULL,
-                 NULL);
+                 const_cast<char *>(processed_command.c_str()),
+                 nullptr,
+                 nullptr);
 
   /* neb module wants to override (or cancel) the event handler - perhaps it will run the eventhandler itself */
   if ((neb_result == NEBERROR_CALLBACKCANCEL)
       || (neb_result == NEBERROR_CALLBACKOVERRIDE)) {
-    delete[] processed_command;
-    delete[] raw_command;
-    delete[] processed_logentry;
-    return ((neb_result == NEBERROR_CALLBACKCANCEL) ? ERROR : OK);
+    return (neb_result == NEBERROR_CALLBACKCANCEL) ? ERROR : OK;
   }
 
   /* run the command */
@@ -780,7 +597,7 @@ int run_global_host_event_handler(nagios_macros* mac, host* hst) {
                config->event_handler_timeout(),
                &early_timeout,
                &exectime,
-               &command_output,
+               command_output,
                0);
   } catch (std::exception const& e) {
     logger(log_runtime_error, basic)
@@ -796,7 +613,7 @@ int run_global_host_event_handler(nagios_macros* mac, host* hst) {
       << config->event_handler_timeout() << " seconds";
 
   /* get end time */
-  gettimeofday(&end_time, NULL);
+  gettimeofday(&end_time, nullptr);
 
   /* send event data to broker */
   broker_event_handler(
@@ -805,8 +622,8 @@ int run_global_host_event_handler(nagios_macros* mac, host* hst) {
     NEBATTR_NONE,
     GLOBAL_HOST_EVENTHANDLER,
     (void*)hst,
-    hst->current_state,
-    hst->state_type,
+    hst->get_current_state(),
+    hst->get_state_type(),
     start_time,
     end_time,
     exectime,
@@ -814,25 +631,20 @@ int run_global_host_event_handler(nagios_macros* mac, host* hst) {
     early_timeout,
     result,
     config->global_host_event_handler().c_str(),
-    processed_command,
-    command_output,
-    NULL);
+    const_cast<char *>(processed_command.c_str()),
+    const_cast<char *>(command_output.c_str()),
+    nullptr);
 
-  /* free memory */
-  delete[] command_output;
-  delete[] raw_command;
-  delete[] processed_command;
-  delete[] processed_logentry;
-
-  return (OK);
+  return OK;
 }
 
 /* runs a host event handler command */
-int run_host_event_handler(nagios_macros* mac, host* hst) {
-  char* raw_command = NULL;
-  char* processed_command = NULL;
-  char* processed_logentry = NULL;
-  char* command_output = NULL;
+int run_host_event_handler(nagios_macros* mac,
+                           com::centreon::engine::host* hst) {
+  std::string raw_command;
+  std::string processed_command;
+  std::string processed_logentry;
+  std::string command_output;
   int early_timeout = false;
   double exectime = 0.0;
   int result = 0;
@@ -844,28 +656,28 @@ int run_host_event_handler(nagios_macros* mac, host* hst) {
   logger(dbg_functions, basic)
     << "run_host_event_handler()";
 
-  if (hst == NULL)
-    return (ERROR);
+  if (hst == nullptr)
+    return ERROR;
 
   /* bail if there's no command */
-  if (hst->event_handler == NULL)
-    return (ERROR);
+  if (hst->get_event_handler().empty())
+    return ERROR;
 
   logger(dbg_eventhandlers, more)
-    << "Running event handler for host '" << hst->name << "'...";
+    << "Running event handler for host '" << hst->get_name() << "'...";
 
   /* get start time */
-  gettimeofday(&start_time, NULL);
+  gettimeofday(&start_time, nullptr);
 
   /* get the raw command line */
   get_raw_command_line_r(
     mac,
-    hst->event_handler_ptr,
-    hst->event_handler,
-    &raw_command,
+    hst->get_event_handler_ptr(),
+    hst->get_event_handler().c_str(),
+    raw_command,
     macro_options);
-  if (raw_command == NULL)
-    return (ERROR);
+  if (raw_command.empty())
+    return ERROR;
 
   logger(dbg_eventhandlers, most)
     << "Raw host event handler command line: " << raw_command;
@@ -874,10 +686,10 @@ int run_host_event_handler(nagios_macros* mac, host* hst) {
   process_macros_r(
     mac,
     raw_command,
-    &processed_command,
+    processed_command,
     macro_options);
-  if (processed_command == NULL)
-    return (ERROR);
+  if (processed_command.empty())
+    return ERROR;
 
   logger(dbg_eventhandlers, most)
     << "Processed host event handler command line: "
@@ -885,13 +697,13 @@ int run_host_event_handler(nagios_macros* mac, host* hst) {
 
   if (config->log_event_handlers() == true) {
     std::ostringstream oss;
-    oss << "HOST EVENT HANDLER: " << hst->name
+    oss << "HOST EVENT HANDLER: " << hst->get_name()
 	<< ";$HOSTSTATE$;$HOSTSTATETYPE$;$HOSTATTEMPT$;"
-	<< hst->event_handler;
+	<< hst->get_event_handler();
     process_macros_r(
       mac,
-      oss.str().c_str(),
-      &processed_logentry,
+      oss.str(),
+      processed_logentry,
       macro_options);
     logger(log_event_handler, basic)
       << processed_logentry;
@@ -906,26 +718,23 @@ int run_host_event_handler(nagios_macros* mac, host* hst) {
                  NEBATTR_NONE,
                  HOST_EVENTHANDLER,
                  (void*)hst,
-                 hst->current_state,
-                 hst->state_type,
+                 hst->get_current_state(),
+                 hst->get_state_type(),
                  start_time,
                  end_time,
                  exectime,
                  config->event_handler_timeout(),
                  early_timeout,
                  result,
-                 hst->event_handler,
-                 processed_command,
-                 NULL,
-                 NULL);
+                 hst->get_event_handler().c_str(),
+                 const_cast<char *>(processed_command.c_str()),
+                 nullptr,
+                 nullptr);
 
   /* neb module wants to override (or cancel) the event handler - perhaps it will run the eventhandler itself */
   if ((neb_result == NEBERROR_CALLBACKCANCEL)
       || (neb_result == NEBERROR_CALLBACKOVERRIDE)) {
-    delete[] processed_command;
-    delete[] raw_command;
-    delete[] processed_logentry;
-    return ((neb_result == NEBERROR_CALLBACKCANCEL) ? ERROR : OK);
+    return (neb_result == NEBERROR_CALLBACKCANCEL) ? ERROR : OK;
   }
 
   /* run the command */
@@ -936,7 +745,7 @@ int run_host_event_handler(nagios_macros* mac, host* hst) {
                config->event_handler_timeout(),
                &early_timeout,
                &exectime,
-               &command_output,
+               command_output,
                0);
   } catch (std::exception const& e) {
     logger(log_runtime_error, basic)
@@ -952,7 +761,7 @@ int run_host_event_handler(nagios_macros* mac, host* hst) {
       << " seconds";
 
   /* get end time */
-  gettimeofday(&end_time, NULL);
+  gettimeofday(&end_time, nullptr);
 
   /* send event data to broker */
   broker_event_handler(
@@ -961,201 +770,23 @@ int run_host_event_handler(nagios_macros* mac, host* hst) {
     NEBATTR_NONE,
     HOST_EVENTHANDLER,
     (void*)hst,
-    hst->current_state,
-    hst->state_type,
+    hst->get_current_state(),
+    hst->get_state_type(),
     start_time,
     end_time,
     exectime,
     config->event_handler_timeout(),
     early_timeout,
     result,
-    hst->event_handler,
-    processed_command,
-    command_output,
-    NULL);
+    hst->get_event_handler().c_str(),
+    const_cast<char *>(processed_command.c_str()),
+    const_cast<char *>(command_output.c_str()),
+    nullptr);
 
-  /* free memory */
-  delete[] command_output;
-  delete[] raw_command;
-  delete[] processed_command;
-  delete[] processed_logentry;
-
-  return (OK);
+  return OK;
 }
 
 /******************************************************************/
 /****************** HOST STATE HANDLER FUNCTIONS ******************/
 /******************************************************************/
 
-/* top level host state handler - occurs after every host check (soft/hard and active/passive) */
-int handle_host_state(host* hst) {
-  int state_change = false;
-  time_t current_time = 0L;
-
-  logger(dbg_functions, basic)
-    << "handle_host_state()";
-
-  /* get current time */
-  time(&current_time);
-
-  /* obsess over this host check */
-  obsessive_compulsive_host_check_processor(hst);
-
-  /* update performance data */
-  update_host_performance_data(hst);
-
-  /* record latest time for current state */
-  switch (hst->current_state) {
-  case HOST_UP:
-    hst->last_time_up = current_time;
-    break;
-
-  case HOST_DOWN:
-    hst->last_time_down = current_time;
-    break;
-
-  case HOST_UNREACHABLE:
-    hst->last_time_unreachable = current_time;
-    break;
-
-  default:
-    break;
-  }
-
-  /* has the host state changed? */
-  if (hst->last_state != hst->current_state
-      || hst->last_hard_state != hst->current_state
-      || (hst->current_state == HOST_UP
-          && hst->state_type == SOFT_STATE))
-    state_change = true;
-
-  /* if the host state has changed... */
-  if (state_change == true) {
-
-    /* update last state change times */
-    if (hst->state_type == SOFT_STATE
-        || hst->last_state != hst->current_state)
-      hst->last_state_change = current_time;
-    if (hst->state_type == HARD_STATE)
-      hst->last_hard_state_change = current_time;
-
-    /* update the event id */
-    hst->last_event_id = hst->current_event_id;
-    hst->current_event_id = next_event_id;
-    next_event_id++;
-
-    /* update the problem id when transitioning to a problem state */
-    if (hst->last_state == HOST_UP) {
-      /* don't reset last problem id, or it will be zero the next time a problem is encountered */
-      /*hst->last_problem_id=hst->current_problem_id; */
-      hst->current_problem_id = next_problem_id;
-      next_problem_id++;
-    }
-
-    /* clear the problem id when transitioning from a problem state to an UP state */
-    if (hst->current_state == HOST_UP) {
-      hst->last_problem_id = hst->current_problem_id;
-      hst->current_problem_id = 0L;
-    }
-
-    /* reset the acknowledgement flag if necessary */
-    if (hst->acknowledgement_type == ACKNOWLEDGEMENT_NORMAL) {
-
-      hst->problem_has_been_acknowledged = false;
-      hst->acknowledgement_type = ACKNOWLEDGEMENT_NONE;
-
-      /* remove any non-persistant comments associated with the ack */
-      delete_host_acknowledgement_comments(hst);
-    }
-    else if (hst->acknowledgement_type == ACKNOWLEDGEMENT_STICKY
-             && hst->current_state == HOST_UP) {
-
-      hst->problem_has_been_acknowledged = false;
-      hst->acknowledgement_type = ACKNOWLEDGEMENT_NONE;
-
-      /* remove any non-persistant comments associated with the ack */
-      delete_host_acknowledgement_comments(hst);
-    }
-
-    /* reset the next and last notification times */
-    hst->last_host_notification = (time_t)0;
-    hst->next_host_notification = (time_t)0;
-
-    /* reset notification suppression option */
-    hst->no_more_notifications = false;
-
-    /* write the host state change to the main log file */
-    if (hst->state_type == HARD_STATE
-        || (hst->state_type == SOFT_STATE
-            && config->log_host_retries() == true))
-      log_host_event(hst);
-
-    /* check for start of flexible (non-fixed) scheduled downtime */
-    /* CHANGED 08-05-2010 EG flex downtime can now start on soft states */
-    /*if(hst->state_type==HARD_STATE) */
-    check_pending_flex_host_downtime(hst);
-
-    if (hst->current_state == HOST_UP) {
-      host_other_props[hst->name].recovery_been_sent = false;
-      host_other_props[hst->name].initial_notif_time = 0;
-    }
-
-    /* notify contacts about the recovery or problem if its a "hard" state */
-    if (hst->state_type == HARD_STATE)
-      host_notification(
-        hst,
-        NOTIFICATION_NORMAL,
-        NULL,
-        NULL,
-        NOTIFICATION_OPTION_NONE);
-
-    /* handle the host state change */
-    handle_host_event(hst);
-
-    /* the host just recovered, so reset the current host attempt */
-    if (hst->current_state == HOST_UP)
-      hst->current_attempt = 1;
-
-    /* the host recovered, so reset the current notification number and state flags (after the recovery notification has gone out) */
-    if (hst->current_state == HOST_UP && host_other_props[hst->name].recovery_been_sent) {
-      hst->current_notification_number = 0;
-      hst->notified_on_down = false;
-      hst->notified_on_unreachable = false;
-    }
-  }
-
-  /* else the host state has not changed */
-  else {
-
-    bool old_recovery_been_sent
-           = host_other_props[hst->name].recovery_been_sent;
-
-    /* notify contacts if needed */
-    if ((hst->current_state != HOST_UP ||
-         (hst->current_state == HOST_UP
-          && !host_other_props[hst->name].recovery_been_sent))
-        && hst->state_type == HARD_STATE)
-      host_notification(
-        hst,
-        NOTIFICATION_NORMAL,
-        NULL,
-        NULL,
-        NOTIFICATION_OPTION_NONE);
-
-    /* the host recovered, so reset the current notification number and state flags (after the recovery notification has gone out) */
-    if (!old_recovery_been_sent
-        && host_other_props[hst->name].recovery_been_sent
-        && hst->current_state == HOST_UP) {
-      hst->current_notification_number = 0;
-      hst->notified_on_down = false;
-      hst->notified_on_unreachable = false;
-    }
-
-    /* if we're in a soft state and we should log host retries, do so now... */
-    if (hst->state_type == SOFT_STATE
-        && config->log_host_retries() == true)
-      log_host_event(hst);
-  }
-
-  return (OK);
-}
