@@ -25,31 +25,31 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include "com/centreon/engine/common.hh"
+#include "com/centreon/engine/configuration/applier/state.hh"
 #include "com/centreon/engine/events/defines.hh"
 #include "com/centreon/engine/globals.hh"
+#include "com/centreon/engine/host.hh"
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/macros.hh"
-#include "com/centreon/engine/objects/command.hh"
-#include "com/centreon/engine/objects/host.hh"
-#include "com/centreon/engine/objects/service.hh"
+#include "com/centreon/engine/service.hh"
 #include "com/centreon/engine/string.hh"
 #include "com/centreon/engine/xpddefault.hh"
-#include "find.hh"
 
 using namespace com::centreon::engine;
+using namespace com::centreon::engine::configuration::applier;
 using namespace com::centreon::engine::logging;
 
-static command*        xpddefault_host_perfdata_command_ptr(NULL);
-static command*        xpddefault_service_perfdata_command_ptr(NULL);
+static commands::command*        xpddefault_host_perfdata_command_ptr(nullptr);
+static commands::command*        xpddefault_service_perfdata_command_ptr(nullptr);
 
-static char*           xpddefault_host_perfdata_file_template(NULL);
-static char*           xpddefault_service_perfdata_file_template(NULL);
+static char*           xpddefault_host_perfdata_file_template(nullptr);
+static char*           xpddefault_service_perfdata_file_template(nullptr);
 
-static command*        xpddefault_host_perfdata_file_processing_command_ptr(NULL);
-static command*        xpddefault_service_perfdata_file_processing_command_ptr(NULL);
+static commands::command*        xpddefault_host_perfdata_file_processing_command_ptr(nullptr);
+static commands::command*        xpddefault_service_perfdata_file_processing_command_ptr(nullptr);
 
-static FILE*           xpddefault_host_perfdata_fp(NULL);
-static FILE*           xpddefault_service_perfdata_fp(NULL);
+static FILE*           xpddefault_host_perfdata_fp(nullptr);
+static FILE*           xpddefault_service_perfdata_fp(nullptr);
 static int             xpddefault_host_perfdata_fd(-1);
 static int             xpddefault_service_perfdata_fd(-1);
 
@@ -62,14 +62,13 @@ static pthread_mutex_t xpddefault_service_perfdata_fp_lock;
 
 // initializes performance data.
 int xpddefault_initialize_performance_data() {
-  char* temp_command_name(NULL);
-  command* temp_command(NULL);
+  char* temp_command_name(nullptr);
 
   // reset vars.
-  xpddefault_host_perfdata_command_ptr = NULL;
-  xpddefault_service_perfdata_command_ptr = NULL;
-  xpddefault_host_perfdata_file_processing_command_ptr = NULL;
-  xpddefault_service_perfdata_file_processing_command_ptr = NULL;
+  xpddefault_host_perfdata_command_ptr = nullptr;
+  xpddefault_service_perfdata_command_ptr = nullptr;
+  xpddefault_host_perfdata_file_processing_command_ptr = nullptr;
+  xpddefault_service_perfdata_file_processing_command_ptr = nullptr;
 
   // grab config info from main config file.
   xpddefault_host_perfdata_file_template = string::dup(config->host_perfdata_file_template());
@@ -90,16 +89,19 @@ int xpddefault_initialize_performance_data() {
     // get the command name, leave any arguments behind.
     temp_command_name = my_strtok(temp_buffer, "!");
 
-    if ((temp_command = find_command(temp_command_name)) == NULL) {
+    command_map::iterator cmd_found = commands::command::commands.find(
+      temp_command_name);
+
+    if (cmd_found == commands::command::commands.end() || !cmd_found->second) {
       logger(log_runtime_warning, basic)
         << "Warning: Host performance command '" << temp_command_name
         << "' was not found - host performance data will not "
         "be processed!";
     }
-    delete[] temp_buffer;
+    else
+      xpddefault_host_perfdata_command_ptr = cmd_found->second.get(); // save the command pointer for later.
 
-    // save the command pointer for later.
-    xpddefault_host_perfdata_command_ptr = temp_command;
+    delete[] temp_buffer;
   }
 
   if (!config->service_perfdata_command().empty()) {
@@ -108,18 +110,20 @@ int xpddefault_initialize_performance_data() {
     // get the command name, leave any arguments behind.
     temp_command_name = my_strtok(temp_buffer, "!");
 
-    if ((temp_command = find_command(temp_command_name)) == NULL) {
+    command_map::iterator cmd_found = commands::command::commands.find(
+      temp_command_name);
+
+    if (cmd_found == commands::command::commands.end() || !cmd_found->second) {
       logger(log_runtime_warning, basic)
         << "Warning: Service performance command '" << temp_command_name
         << "' was not found - service performance data will not "
         "be processed!";
     }
+    else
+      xpddefault_service_perfdata_command_ptr = cmd_found->second.get();
 
     // free memory.
     delete[] temp_buffer;
-
-    // save the command pointer for later.
-    xpddefault_service_perfdata_command_ptr = temp_command;
   }
 
   if (!config->host_perfdata_file_processing_command().empty()) {
@@ -128,18 +132,20 @@ int xpddefault_initialize_performance_data() {
 
     // get the command name, leave any arguments behind.
     temp_command_name = my_strtok(temp_buffer, "!");
-    if ((temp_command = find_command(temp_command_name)) == NULL) {
+    command_map::iterator cmd_found = commands::command::commands.find(
+      temp_command_name);
+
+    if (cmd_found == commands::command::commands.end() || !cmd_found->second) {
       logger(log_runtime_warning, basic)
         << "Warning: Host performance file processing command '"
         << temp_command_name << "' was not found - host performance "
         "data file will not be processed!";
     }
+    else
+      xpddefault_host_perfdata_file_processing_command_ptr = cmd_found->second.get();
 
     // free memory.
     delete[] temp_buffer;
-
-    // save the command pointer for later.
-    xpddefault_host_perfdata_file_processing_command_ptr = temp_command;
   }
 
   if (!config->service_perfdata_file_processing_command().empty()) {
@@ -148,22 +154,22 @@ int xpddefault_initialize_performance_data() {
 
     // get the command name, leave any arguments behind.
     temp_command_name = my_strtok(temp_buffer, "!");
-    if ((temp_command = find_command(temp_command_name)) == NULL) {
+    command_map::iterator cmd_found = commands::command::commands.find(
+      temp_command_name);
+
+    if (cmd_found == commands::command::commands.end() || !cmd_found->second) {
       logger(log_runtime_warning, basic)
         << "Warning: Service performance file processing command '"
         << temp_command_name << "' was not found - service performance "
         "data file will not be processed!";
     }
-
+    else
+      xpddefault_service_perfdata_file_processing_command_ptr = cmd_found->second.get();
     // free memory.
     delete[] temp_buffer;
-
-    // save the command pointer for later.
-    xpddefault_service_perfdata_file_processing_command_ptr
-      = temp_command;
   }
 
-  return (OK);
+  return OK;
 }
 
 // cleans up performance data.
@@ -172,14 +178,14 @@ int xpddefault_cleanup_performance_data() {
   delete[] xpddefault_host_perfdata_file_template;
   delete[] xpddefault_service_perfdata_file_template;
 
-  xpddefault_host_perfdata_file_template = NULL;
-  xpddefault_service_perfdata_file_template = NULL;
+  xpddefault_host_perfdata_file_template = nullptr;
+  xpddefault_service_perfdata_file_template = nullptr;
 
   // close the files.
   xpddefault_close_host_perfdata_file();
   xpddefault_close_service_perfdata_file();
 
-  return (OK);
+  return OK;
 }
 
 /******************************************************************/
@@ -187,28 +193,21 @@ int xpddefault_cleanup_performance_data() {
 /******************************************************************/
 
 // updates service performance data.
-int xpddefault_update_service_performance_data(service* svc) {
+int xpddefault_update_service_performance_data(com::centreon::engine::service* svc) {
   nagios_macros mac;
-  host* hst(NULL);
 
   /*
    * bail early if we've got nothing to do so we don't spend a lot
    * of time calculating macros that never get used
    */
-  if (!svc || !svc->perf_data || !*svc->perf_data)
-    return (OK);
+  if (!svc || svc->get_perf_data().empty())
+    return OK;
   if ((!xpddefault_service_perfdata_fp
        || !xpddefault_service_perfdata_file_template)
       && config->service_perfdata_command().empty())
-    return (OK);
+    return OK;
 
-  /*
-   * we know we've got some work to do, so grab the necessary
-   * macros and get busy
-   */
-  memset(&mac, 0, sizeof(mac));
-  hst = find_host(svc->host_name);
-  grab_host_macros_r(&mac, hst);
+  grab_host_macros_r(&mac, svc->get_host_ptr());
   grab_service_macros_r(&mac, svc);
 
   // run the performance data command.
@@ -223,7 +222,7 @@ int xpddefault_update_service_performance_data(service* svc) {
   // now free() it all.
   clear_volatile_macros_r(&mac);
 
-  return (OK);
+  return OK;
 }
 
 
@@ -235,15 +234,14 @@ int xpddefault_update_host_performance_data(host* hst) {
    * bail early if we've got nothing to do so we don't spend a lot
    * of time calculating macros that never get used
    */
-  if (!hst || !hst->perf_data || !*hst->perf_data)
-    return (OK);
+  if (!hst || !hst->get_perf_data().empty())
+    return OK;
   if ((!xpddefault_host_perfdata_fp
        || !xpddefault_host_perfdata_file_template)
       && config->host_perfdata_command().empty())
-    return (OK);
+    return OK;
 
   // set up macros and get to work.
-  memset(&mac, 0, sizeof(mac));
   grab_host_macros_r(&mac, hst);
 
   // run the performance data command.
@@ -258,7 +256,7 @@ int xpddefault_update_host_performance_data(host* hst) {
   // free() all.
   clear_volatile_macros_r(&mac);
 
-  return (OK);
+  return OK;
 }
 
 /******************************************************************/
@@ -268,9 +266,9 @@ int xpddefault_update_host_performance_data(host* hst) {
 // runs the service performance data command.
 int xpddefault_run_service_performance_data_command(
       nagios_macros* mac,
-      service* svc) {
-  char* raw_command_line(NULL);
-  char* processed_command_line(NULL);
+      com::centreon::engine::service* svc) {
+  std::string raw_command_line;
+  std::string processed_command_line;
   int early_timeout(false);
   double exectime;
   int result(OK);
@@ -279,22 +277,22 @@ int xpddefault_run_service_performance_data_command(
   logger(dbg_functions, basic)
     << "run_service_performance_data_command()";
 
-  if (svc == NULL)
-    return (ERROR);
+  if (svc == nullptr)
+    return ERROR;
 
   // we don't have a command.
   if (config->service_perfdata_command().empty())
-    return (OK);
+    return OK;
 
   // get the raw command line.
   get_raw_command_line_r(
     mac,
     xpddefault_service_perfdata_command_ptr,
     config->service_perfdata_command().c_str(),
-    &raw_command_line,
+    raw_command_line,
     macro_options);
-  if (raw_command_line == NULL)
-    return (ERROR);
+  if (raw_command_line.c_str())
+    return ERROR;
 
   logger(dbg_perfdata, most)
     << "Raw service performance data command line: "
@@ -304,10 +302,10 @@ int xpddefault_run_service_performance_data_command(
   process_macros_r(
     mac,
     raw_command_line,
-    &processed_command_line,
+    processed_command_line,
     macro_options);
-  if (processed_command_line == NULL)
-    return (ERROR);
+  if (processed_command_line.empty())
+    return ERROR;
 
   logger(dbg_perfdata, most)
     << "Processed service performance data "
@@ -315,13 +313,14 @@ int xpddefault_run_service_performance_data_command(
 
   // run the command.
   try {
+    std::string tmp;
     my_system_r(
       mac,
       processed_command_line,
       config->perfdata_timeout(),
       &early_timeout,
       &exectime,
-      NULL,
+      tmp,
       0);
   } catch (std::exception const& e) {
     logger(log_runtime_error, basic)
@@ -334,23 +333,19 @@ int xpddefault_run_service_performance_data_command(
     logger(log_runtime_warning, basic)
       << "Warning: Service performance data command '"
       << processed_command_line << "' for service '"
-      << svc->description << "' on host '"
-      << svc->host_name << "' timed out after "
+      << svc->get_description() << "' on host '"
+      << svc->get_hostname() << "' timed out after "
       << config->perfdata_timeout() << " seconds";
 
-  // free memory.
-  delete[] raw_command_line;
-  delete[] processed_command_line;
-
-  return (result);
+  return result;
 }
 
 // runs the host performance data command.
 int xpddefault_run_host_performance_data_command(
       nagios_macros* mac,
       host* hst) {
-  char* raw_command_line(NULL);
-  char* processed_command_line(NULL);
+  std::string raw_command_line;
+  std::string processed_command_line;
   int early_timeout(false);
   double exectime;
   int result(OK);
@@ -359,22 +354,22 @@ int xpddefault_run_host_performance_data_command(
   logger(dbg_functions, basic)
     << "run_host_performance_data_command()";
 
-  if (hst == NULL)
-    return (ERROR);
+  if (hst == nullptr)
+    return ERROR;
 
   // we don't have a command.
   if (config->host_perfdata_command().empty())
-    return (OK);
+    return OK;
 
   // get the raw command line.
   get_raw_command_line_r(
     mac,
     xpddefault_host_perfdata_command_ptr,
     config->host_perfdata_command().c_str(),
-    &raw_command_line,
+    raw_command_line,
     macro_options);
-  if (raw_command_line == NULL)
-    return (ERROR);
+  if (raw_command_line.empty())
+    return ERROR;
 
   logger(dbg_perfdata, most)
     << "Raw host performance data command line: " << raw_command_line;
@@ -383,7 +378,7 @@ int xpddefault_run_host_performance_data_command(
   process_macros_r(
     mac,
     raw_command_line,
-    &processed_command_line,
+    processed_command_line,
     macro_options);
 
   logger(dbg_perfdata, most)
@@ -392,13 +387,14 @@ int xpddefault_run_host_performance_data_command(
 
   // run the command.
   try {
+    std::string tmp;
     my_system_r(
       mac,
       processed_command_line,
       config->perfdata_timeout(),
       &early_timeout,
       &exectime,
-      NULL,
+      tmp,
       0);
   } catch (std::exception const& e) {
     logger(log_runtime_error, basic)
@@ -406,22 +402,18 @@ int xpddefault_run_host_performance_data_command(
       << processed_command_line << "' : " << e.what();
   }
 
-  if (processed_command_line == NULL)
-    return (ERROR);
+  if (processed_command_line.empty())
+    return ERROR;
 
   // check to see if the command timed out.
   if (early_timeout == true)
     logger(log_runtime_warning, basic)
       << "Warning: Host performance data command '"
-      << processed_command_line << "' for host '" << hst->name
+      << processed_command_line << "' for host '" << hst->get_name()
       << "' timed out after " << config->perfdata_timeout()
       << " seconds";
 
-  // free memory.
-  delete[] raw_command_line;
-  delete[] processed_command_line;
-
-  return (result);
+  return result;
 }
 
 /******************************************************************/
@@ -444,17 +436,17 @@ int xpddefault_open_host_perfdata_file() {
             config->host_perfdata_file().c_str(),
             (config->host_perfdata_file_mode() == configuration::state::mode_file) ? "w" : "a");
 
-    if (xpddefault_host_perfdata_fp == NULL) {
+    if (xpddefault_host_perfdata_fp == nullptr) {
       logger(log_runtime_warning, basic)
         << "Warning: File '" << xpddefault_host_perfdata_fp
         << "' could not be opened - host performance data will not "
         "be written to file!";
 
-      return (ERROR);
+      return ERROR;
     }
   }
 
-  return (OK);
+  return OK;
 }
 
 // open the service performance data file for writing.
@@ -473,109 +465,104 @@ int xpddefault_open_service_perfdata_file() {
           config->service_perfdata_file().c_str(),
           (config->service_perfdata_file_mode() == configuration::state::mode_file) ? "w" : "a");
 
-    if (xpddefault_service_perfdata_fp == NULL) {
+    if (xpddefault_service_perfdata_fp == nullptr) {
       logger(log_runtime_warning, basic)
         << "Warning: File '" << config->service_perfdata_file()
         << "' could not be opened - service performance data will not "
         "be written to file!";
 
-      return (ERROR);
+      return ERROR;
     }
   }
 
-  return (OK);
+  return OK;
 }
 
 // close the host performance data file.
 int xpddefault_close_host_perfdata_file() {
-  if (xpddefault_host_perfdata_fp != NULL)
+  if (xpddefault_host_perfdata_fp != nullptr)
     fclose(xpddefault_host_perfdata_fp);
   if (xpddefault_host_perfdata_fd >= 0) {
     close(xpddefault_host_perfdata_fd);
     xpddefault_host_perfdata_fd = -1;
   }
 
-  return (OK);
+  return OK;
 }
 
 // close the service performance data file.
 int xpddefault_close_service_perfdata_file() {
-  if (xpddefault_service_perfdata_fp != NULL)
+  if (xpddefault_service_perfdata_fp != nullptr)
     fclose(xpddefault_service_perfdata_fp);
   if (xpddefault_service_perfdata_fd >= 0) {
     close(xpddefault_service_perfdata_fd);
     xpddefault_service_perfdata_fd = -1;
   }
 
-  return (OK);
+  return OK;
 }
 
 // processes delimiter characters in templates.
 void xpddefault_preprocess_file_templates(char* tmpl) {
-  char* tempbuf;
-  size_t x(0);
-  size_t y(0);
+  if (!tmpl)
+    return ;
+  char* tmp1{tmpl}, *tmp2{tmpl};
 
-  // allocate temporary buffer.
-  tempbuf = new char[strlen(tmpl) + 1];
-  strcpy(tempbuf, "");
-
-  for (x = 0, y = 0; x < strlen(tmpl); x++, y++) {
-    if (tmpl[x] == '\\') {
-      if (tmpl[x + 1] == 't') {
-        tempbuf[y] = '\t';
-        x++;
+  for (; *tmp1 != 0; tmp1++, tmp2++) {
+    if (*tmp1 == '\\') {
+      switch (tmp1[1]) {
+        case 't':
+          *tmp2 = '\t';
+          tmp1++;
+          break;
+        case 'r':
+          *tmp2 = '\r';
+          tmp1++;
+          break;
+        case 'n':
+          *tmp2 = '\n';
+          tmp1++;
+          break;
+        default:
+          *tmp2 = *tmp1;
+          break;
       }
-      else if (tmpl[x + 1] == 'r') {
-        tempbuf[y] = '\r';
-        x++;
-      }
-      else if (tmpl[x + 1] == 'n') {
-        tempbuf[y] = '\n';
-        x++;
-      }
-      else
-        tempbuf[y] = tmpl[x];
     }
     else
-      tempbuf[y] = tmpl[x];
+      *tmp2 = *tmp1;
   }
-  tempbuf[y] = '\x0';
-
-  strcpy(tmpl, tempbuf);
-  delete[] tempbuf;
-  return;
+  *tmp2 = 0;
 }
 
 // updates service performance data file.
 int xpddefault_update_service_performance_data_file(
       nagios_macros* mac,
-      service* svc) {
-  char* raw_output(NULL);
-  char* processed_output(NULL);
+      com::centreon::engine::service* svc) {
+  std::string raw_output;
+  std::string processed_output;
   int result(OK);
 
   logger(dbg_functions, basic)
     << "update_service_performance_data_file()";
 
-  if (svc == NULL)
-    return (ERROR);
+  if (svc == nullptr)
+    return ERROR;
 
   // we don't have a file to write to.
-  if (xpddefault_service_perfdata_fp == NULL
-      || xpddefault_service_perfdata_file_template == NULL)
-    return (OK);
+  if (xpddefault_service_perfdata_fp == nullptr
+      || xpddefault_service_perfdata_file_template == nullptr)
+    return OK;
 
   // get the raw line to write.
-  raw_output = string::dup(xpddefault_service_perfdata_file_template);
+  raw_output = xpddefault_service_perfdata_file_template;
 
   logger(dbg_perfdata, most)
     << "Raw service performance data file output: " << raw_output;
 
   // process any macros in the raw output line.
-  process_macros_r(mac, raw_output, &processed_output, 0);
-  if (processed_output == NULL)
-    return (ERROR);
+  process_macros_r(mac, raw_output, processed_output, 0);
+  if (processed_output.empty())
+    return ERROR;
 
   logger(dbg_perfdata, most)
     << "Processed service performance data file output: "
@@ -583,36 +570,32 @@ int xpddefault_update_service_performance_data_file(
 
   // lock, write to and unlock host performance data file.
   pthread_mutex_lock(&xpddefault_service_perfdata_fp_lock);
-  fputs(processed_output, xpddefault_service_perfdata_fp);
+  fputs(processed_output.c_str(), xpddefault_service_perfdata_fp);
   fputc('\n', xpddefault_service_perfdata_fp);
   fflush(xpddefault_service_perfdata_fp);
   pthread_mutex_unlock(&xpddefault_service_perfdata_fp_lock);
 
-  // free memory.
-  delete[] raw_output;
-  delete[] processed_output;
-
-  return (result);
+  return result;
 }
 
 // updates host performance data file.
 int xpddefault_update_host_performance_data_file(
       nagios_macros* mac,
       host* hst) {
-  char* raw_output(NULL);
-  char* processed_output(NULL);
+  std::string raw_output;
+  std::string processed_output;
   int result(OK);
 
   logger(dbg_functions, basic)
     << "update_host_performance_data_file()";
 
-  if (hst == NULL)
-    return (ERROR);
+  if (hst == nullptr)
+    return ERROR;
 
   // we don't have a host perfdata file.
-  if (xpddefault_host_perfdata_fp == NULL
-      || xpddefault_host_perfdata_file_template == NULL)
-    return (OK);
+  if (xpddefault_host_perfdata_fp == nullptr
+      || xpddefault_host_perfdata_file_template == nullptr)
+    return OK;
 
   // get the raw output.
   raw_output = string::dup(xpddefault_host_perfdata_file_template);
@@ -621,9 +604,9 @@ int xpddefault_update_host_performance_data_file(
     << "Raw host performance file output: " << raw_output;
 
   // process any macros in the raw output.
-  process_macros_r(mac, raw_output, &processed_output, 0);
-  if (processed_output == NULL)
-    return (ERROR);
+  process_macros_r(mac, raw_output, processed_output, 0);
+  if (processed_output.empty())
+    return ERROR;
 
   logger(dbg_perfdata, most)
     << "Processed host performance data file output: "
@@ -631,22 +614,18 @@ int xpddefault_update_host_performance_data_file(
 
   // lock, write to and unlock host performance data file.
   pthread_mutex_lock(&xpddefault_host_perfdata_fp_lock);
-  fputs(processed_output, xpddefault_host_perfdata_fp);
+  fputs(processed_output.c_str(), xpddefault_host_perfdata_fp);
   fputc('\n', xpddefault_host_perfdata_fp);
   fflush(xpddefault_host_perfdata_fp);
   pthread_mutex_unlock(&xpddefault_host_perfdata_fp_lock);
 
-  // free memory.
-  delete[] raw_output;
-  delete[] processed_output;
-
-  return (result);
+  return result;
 }
 
 // periodically process the host perf data file.
 int xpddefault_process_host_perfdata_file() {
-  char* raw_command_line(NULL);
-  char* processed_command_line(NULL);
+  std::string raw_command_line;
+  std::string processed_command_line;
   int early_timeout(false);
   double exectime(0.0);
   int result(OK);
@@ -658,21 +637,18 @@ int xpddefault_process_host_perfdata_file() {
 
   // we don't have a command.
   if (config->host_perfdata_file_processing_command().empty())
-    return (OK);
-
-  // init macros.
-  memset(&mac, 0, sizeof(mac));
+    return OK;
 
   // get the raw command line.
   get_raw_command_line_r(
     &mac,
     xpddefault_host_perfdata_file_processing_command_ptr,
     config->host_perfdata_file_processing_command().c_str(),
-    &raw_command_line,
+    raw_command_line,
     macro_options);
-  if (raw_command_line == NULL) {
+  if (raw_command_line.empty()) {
     clear_volatile_macros_r(&mac);
-    return (ERROR);
+    return ERROR;
   }
 
   logger(dbg_perfdata, most)
@@ -683,11 +659,11 @@ int xpddefault_process_host_perfdata_file() {
   process_macros_r(
     &mac,
     raw_command_line,
-    &processed_command_line,
+    processed_command_line,
     macro_options);
-  if (processed_command_line == NULL) {
+  if (processed_command_line.empty()) {
     clear_volatile_macros_r(&mac);
-    return (ERROR);
+    return ERROR;
   }
 
   logger(dbg_perfdata, most)
@@ -700,13 +676,14 @@ int xpddefault_process_host_perfdata_file() {
 
   // run the command.
   try {
+    std::string tmp;
     my_system_r(
       &mac,
       processed_command_line,
       config->perfdata_timeout(),
       &early_timeout,
       &exectime,
-      NULL,
+      tmp,
       0);
   } catch (std::exception const& e) {
     logger(log_runtime_error, basic)
@@ -726,18 +703,13 @@ int xpddefault_process_host_perfdata_file() {
       << "Warning: Host performance data file processing command '"
       << processed_command_line << "' timed out after "
       << config->perfdata_timeout() << " seconds";
-
-  // free memory.
-  delete[] raw_command_line;
-  delete[] processed_command_line;
-
-  return (result);
+  return result;
 }
 
 // periodically process the service perf data file.
 int xpddefault_process_service_perfdata_file() {
-  char* raw_command_line(NULL);
-  char* processed_command_line(NULL);
+  std::string raw_command_line;
+  std::string processed_command_line;
   int early_timeout(false);
   double exectime(0.0);
   int result(OK);
@@ -749,21 +721,18 @@ int xpddefault_process_service_perfdata_file() {
 
   // we don't have a command.
   if (config->service_perfdata_file_processing_command().empty())
-    return (OK);
-
-  // init macros.
-  memset(&mac, 0, sizeof(mac));
+    return OK;
 
   // get the raw command line.
   get_raw_command_line_r(
     &mac,
     xpddefault_service_perfdata_file_processing_command_ptr,
     config->service_perfdata_file_processing_command().c_str(),
-    &raw_command_line,
+    raw_command_line,
     macro_options);
-  if (raw_command_line == NULL) {
+  if (raw_command_line.empty()) {
     clear_volatile_macros_r(&mac);
-    return (ERROR);
+    return ERROR;
   }
 
   logger(dbg_perfdata, most)
@@ -774,11 +743,11 @@ int xpddefault_process_service_perfdata_file() {
   process_macros_r(
     &mac,
     raw_command_line,
-    &processed_command_line,
+    processed_command_line,
     macro_options);
-  if (processed_command_line == NULL) {
+  if (processed_command_line.empty()) {
     clear_volatile_macros_r(&mac);
-    return (ERROR);
+    return ERROR;
   }
 
   logger(dbg_perfdata, most)
@@ -791,13 +760,14 @@ int xpddefault_process_service_perfdata_file() {
 
   // run the command.
   try {
+    std::string tmp;
     my_system_r(
       &mac,
       processed_command_line,
       config->perfdata_timeout(),
       &early_timeout,
       &exectime,
-      NULL,
+      tmp,
       0);
   } catch (std::exception const& e) {
     logger(log_runtime_error, basic)
@@ -820,8 +790,5 @@ int xpddefault_process_service_perfdata_file() {
       << config->perfdata_timeout() << " seconds";
 
   // free memory.
-  delete[] raw_command_line;
-  delete[] processed_command_line;
-
-  return (result);
+  return result;
 }
